<?php
/*******************************************************************************
 *  Copyright IBM Corp. 2007 All rights reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *********************************************************************************/


/**
 * The Connection Class is used to create a connection to either a DB2, Apache Derby or Cloudscape
 * database. It supports either a direct connection to a hostname and port number
 * or a connection through a DB2 Client.
*/

/** Statement Class */
include_once(PHP_INCLUDE_BASE_DIRECTORY . DB_STATEMENT);

/** The Connection Class is used to create a connection to either a DB2, Apache Derby or Cloudscape
 * database. It supports either a direct connection to a hostname and port number
 * or a connection through a DB2 Client. */
class Connection {

	/** Boolean indicating whether you are using a cataloged or direct connection
	* @var boolean */
	public $cataloged = false;
	/** Database name
	* @var boolean */
	public $database = "";
	/** Connection Description name
	* @var boolean */
	public $description = "";
	/** Schema name
	* @var string */
	public $schema = "";
    /** User Name
    * @var string */
	public $username = "";
    /** Password
    * @var string */
	public $password = "";
    /** Hostname
    * @var string */
	public $hostname = "";
    /** Database port number
    * @var string */
	public $portnumber = "";
    /** Database connection resource
    * @var resource */
	public $dbconn = false;
    /** Set TRUE is a valid connection exists
    * @var boolean */
	public $connected = false;
    /** State of the connection
    * @var string */
	public $SQLState = 0;
    /** An Error message if one exsists
    * @var string */
	public $SQLErrorMSG = "";
	  /** Indicates weather to save the connection
    * @var string */
	public $saveConnection = NULL;
	  /** Indicates weather to use a presistent connection
    * @var string */
	public $usePersistentConnection = USE_PERSISTENT_CONNECTION;
	/** Set TRUE trustedContext is enabled
    * @var boolean */
	public $trustedContextEnabled = false;
	/** Indicated the PHP extension used
	 * set to null if non is needed
	 * @var string */
	public static $requiredDBExtension = "ibm_db2";
	/** Indicated the PHP extension minimum version needed
	 * set to null if non is needed
	 * @var float */
	public static $requiredDBExtensionMinVersion = 1.6;

	function driverCheck()
	{
		if(ENABLE_PHP_EXTENSION_CHECK)
		{
			$extension_version = phpversion(Connection::$requiredDBExtension);
			if($extension_version === false)
			{
				$this->SQLState = -1;
				$this->SQLErrorMSG = "The " . Connection::$requiredDBExtension . " PHP module was not found.";
				return false;
			}
			elseif($extension_version < Connection::$requiredDBExtensionMinVersion)
			{
				$this->SQLState = -2;
				$this->SQLErrorMSG = "Upgrade to latest " . Connection::$requiredDBExtension . " PHP module. v" . $extension_version . " is installed a minimum of v" .Connection::$requiredDBExtensionMinVersion . "  is required.";
				return false;
			}
		}
		return true;
	}

	/**
	  * Requires a database name, schema, userid and password.
	  * If the hostname and portnumber are also included it will try to connect directly to the database.
	  * With only a database name, it will try to connect through a local DB2 Client.
	*/
	function Connection($database, $schema, $username, $password, $hostname, $portnumber, $usePersistentConnection = USE_PERSISTENT_CONNECTION, $enableTrustedContext = false) {

		if(!@$this->driverCheck()) return;

		$usePersistentConnection = $usePersistentConnection == "" || $usePersistentConnection == null ? USE_PERSISTENT_CONNECTION : $usePersistentConnection;

		if(FORCE_CONNECTION_WITH_DEFAULT)
		{
			$this->description = DEFAULT_DB2_DATABASE_USERNAME . "@" . DEFAULT_DB2_DATABASE . "." . (DEFAULT_DB2_DATABASE_HOST_NAME != "" ? DEFAULT_DB2_DATABASE_HOST_NAME . ":" . DEFAULT_DB2_DATABASE_PORT_NUMBER : "" );
			$this->database = DEFAULT_DB2_DATABASE;

			@session_start();

			$this->schema = isset($_SESSION['Connections'][USE_DATABASE_CONNECTION]['schema']) ? $_SESSION['Connections'][USE_DATABASE_CONNECTION]['schema'] : DEFAULT_DB2_DATABASE_SCHEMA;

			session_write_close();

			$this->username = DEFAULT_DB2_DATABASE_USERNAME;
			$this->password = DEFAULT_DB2_DATABASE_PASSWORD;
			$this->hostname = DEFAULT_DB2_DATABASE_HOST_NAME;
			$this->portnumber = DEFAULT_DB2_DATABASE_PORT_NUMBER;
			$this->usePersistentConnection = USE_PERSISTENT_CONNECTION;
		}
		else
		{
			$this->description = $username . "@" . $database . ($hostname != "" ? "." . $hostname . ":" . $portnumber : "" );
			$this->database = $database;
			$this->schema = $schema =! "" && $schema != null ? $schema : $username;
			$this->username = $username;
			$this->password = $password;
			$this->hostname = $hostname;
			$this->portnumber = $portnumber;
			$this->usePersistentConnection = $usePersistentConnection;
		}

		$this->trustedContextEnabled = $enableTrustedContext;

        if(trim($this->description) == "@")
            $this->description = "";

        $this->cataloged = ($this->hostname == "" | $this->portnumber == "") ? true : false;

		if($this->database == "" && $this->username == "")
			return;

		$optionArray = array();

		if($this->trustedContextEnabled)
		{
			$optionArray['trustedcontext'] = DB2_TRUSTED_CONTEXT_ENABLE;
		}
		/** db2_connect returns 0 if the connection attempt fails;
		  * otherwise it returns a connection ID used by other DB2 functions */

		if($this->usePersistentConnection)
		{
			if ($this->cataloged) {
				$this->dbconn = db2_pconnect($this->database, $this->username, $this->password, $optionArray);
			}
			else {
				$connectionString = "HOSTNAME=$this->hostname;DATABASE=$this->database;PROTOCOL=TCPIP;PORT=$this->portnumber;UID=$this->username;PWD=$this->password;";
				$this->dbconn = db2_pconnect($connectionString, NULL, NULL, $optionArray);
			}
		}
		else
		{
			if ($this->cataloged) {
				$this->dbconn = db2_connect($this->database, $this->username, $this->password, $optionArray);
			}
			else {
				$connectionString = "HOSTNAME=$this->hostname;DATABASE=$this->database;PROTOCOL=TCPIP;PORT=$this->portnumber;UID=$this->username;PWD=$this->password;";
				$this->dbconn = db2_connect($connectionString, NULL, NULL, $optionArray);
			}
		}

		if ($this->dbconn === false) {
			$this->SQLState = db2_conn_error();
			$this->SQLErrorMSG = db2_conn_errormsg();
			if (DEBUG_MODE_ENABLED && db2_conn_errormsg() != "") {
				echo("Connection to database failed.");
				$sqlerror = $this->SQLErrorMSG;
				echo($sqlState);
			}
			$this->connected = false;

		}
		else {

			$time = date('y.d.m:H:i:s');
			$options = array(
					'wrkstnname' => 'TEr' . MAJOR_VERSION . "." . MINOR_VERSION . "." . SUB_VERSION . '_on_' . $username . "@" . $_SERVER['SERVER_ADDR'] . "_FROM_" . $_SERVER['REMOTE_ADDR'] . "_at_" . $time,
					'applname' => 'TEr' . MAJOR_VERSION . "." . MINOR_VERSION . "." . SUB_VERSION . '_on_' . $username . "@" . $_SERVER['SERVER_ADDR'] . "_FROM_" . $_SERVER['REMOTE_ADDR'] . "_at_" . $time
					);

			db2_set_option($this->dbconn, $options, 1);


			$this->setSchema();
			$this->connected = true;
		}
		if($this->cataloged = "")
		{
			$this->hostname = "LOCAL";
			$this->portnumber = "LOCAL";
		}
	}

	static function testConnection($database, $username, $password, $hostname, $portnumber, $usePersistentConnection = USE_PERSISTENT_CONNECTION) {

		$usePersistentConnection = $usePersistentConnection == "" || $usePersistentConnection == null ? USE_PERSISTENT_CONNECTION : $usePersistentConnection;

		$dbconn = null;

		$cataloged = ($hostname == "" | $portnumber == "") ? true : false;

		if(trim($database) == "")
			return "No database specified!";
		if(trim($username) == "")
			return "No username specified!";
			
		if($usePersistentConnection)
		{
			if ($cataloged) {
				$dbconn = db2_pconnect($database, $username, $password);
			}
			else {
				$connectionString = "HOSTNAME=$hostname;DATABASE=$database;PROTOCOL=TCPIP;PORT=$portnumber;UID=$username;PWD=$password;";
				$dbconn = db2_pconnect($connectionString, NULL, NULL);
			}
		}
		else
		{
			if ($cataloged) {
				$dbconn = db2_connect($database, $username, $password);
			}
			else {
				$connectionString = "HOSTNAME=$hostname;DATABASE=$database;PROTOCOL=TCPIP;PORT=$portnumber;UID=$username;PWD=$password;";
				$dbconn = db2_connect($connectionString, NULL, NULL);
			}
		}

		if ($dbconn === false)
		{
			$returnedError = db2_conn_errormsg();
			return $returnedError == "" ? "No error given. " . db2_conn_error() : $returnedError;
		}

		$data = db2_server_info($dbconn);
		$major = 0;
		$minor = 0;
		$sub = 0;
		if($data === false)
			return false;
		$returnObject = array();
		$returnObject['dataServerName'] = $data->DBMS_NAME;
		$version = explode(".", $data->DBMS_VER);
		if($version !== false)
		{
			$returnObject['dataServerVersion'] = ((int)$version[0]) . "." . ((int)$version[1]);
			$returnObject['dataServerFixpack'] = ((int)$version[2]);
		}
		
		$returnObject['dataServerInstance'] = $data->INST_NAME;
		$returnObject['dataServerTransactionIsolation'] =  $data->DFT_ISOLATION;
		$returnObject['dataServerCodepage'] =  $data->DB_CODEPAGE;
		$returnObject['dataServerSQLConformance'] =  $data->SQL_CONFORMANCE;
		$returnObject['dataServerDefaultIsolationLevel'] =  $data->DFT_ISOLATION;

		return $returnObject;
	}

	function setTrustedContextUsers($userName, $password)
	{
		if(!$this->trustedContextEnabled || $this->dbconn === false)
		{
			$this->connected = false;
			$this->SQLErrorMSG = 'Trusted context has not been enabled.';
			$this->dbconn = false;
			return $this;
		}

		if(!db2_get_option($this->dbconn, "trustedcontext"))
		{
			$this->connected = false;
			$this->SQLErrorMSG = 'Trusted context has not been enabled on this connection.';
			$this->dbconn = false;
			return $this;
		}

		if(db2_set_option($this->dbconn, array('trusted_user' => $userName, 'trusted_password' => $password), 1))
		{
			if($userName == db2_get_option($this->dbconn, "trusted_user"))
			{
				$this->connected = true;
				$this->SQLErrorMSG = 'User has been switched.';
				return $this;
			}
		}
		$this->connected = false;
		$this->SQLErrorMSG = 'Could not set trusted context user.';
		$this->dbconn = false;
		return $this;
	}

	function testTrustedContextUser($userName, $password)
	{
		$ConnOpAry = array('trustedcontext' => DB2_TRUSTED_CONTEXT_ENABLE);
		$dbconn = false;
		if($this->dbconn !== false)
		{
			db2_close($this->dbconn);
			$this->dbconn = false;
		}

		$cataloged = ($this->hostname == "" | $this->portnumber == "") ? true : false;
		if ($cataloged) {
				$dbconn = db2_connect($this->database, $this->username, $this->password, $ConnOpAry);
		}
		else {
			$connectionString = "HOSTNAME=$this->hostname;DATABASE=$this->database;PROTOCOL=TCPIP;PORT=$this->portnumber;UID=$this->username;PWD=$this->password;";
			$dbconn = db2_connect($connectionString, NULL, NULL, $ConnOpAry);
		}

		if($dbconn === false)
		{
			return array(false, "Could not establish database connection with trusted context enabled.\n" . db2_conn_errormsg());
		}

		if($this->trustedContextEnabled || !db2_get_option($dbconn, "trustedcontext"))
		{
			db2_close($dbconn);
			return array(false, 'Trusted contest has not been enabled on this connection.');
		}

		if(db2_set_option($dbconn, array('trusted_user' => $userName, 'trusted_password' => $password), 1))
		{
			if($userName == db2_get_option($dbconn, "trusted_user"))
			{
				db2_close($dbconn);
				return array(true, 'Trusted user is valid.');
			}
		}
		db2_close($dbconn);
		return array(false, 'Could not set trusted context user.');
	}

	/**
	 * Sets the autocommit
	 * @return resource
	 */
	function setAutoCommit($SQLAdHoc_AutoCommit) {
		return @db2_autocommit($this->dbconn, $SQLAdHoc_AutoCommit);
	}

	/**
	 * executs a commit
	 * @return resource
	 */
	function commit() {
		return @db2_commit($this->dbconn);
	}

	/**
	 * Executs a rollback
	 * @return resource
	 */
	function rollback() {
		return @db2_rollback($this->dbconn);
	}


	/**
	 * Returns TRUE is a valid connection was established.
	 * @return boolean
	 */
	function connected() {
		return $this->connected;
	}

	/**
	 * Returns TRUE is a valid connection was established.
	 * @return boolean
	 */
	function dbconn() {
		return $this->dbconn;
	}

	/**
	 * Sets the database schema for all subsequent database requests.
	 *
	 * If the schema variable is blank the schema is set by default
	 * to the schema corresponding to the username.
	 */
	function setSchema($schema = null) {
		$setCurrentPath = "SET CURRENT PATH ";
		$setCurrentSchema = "SET CURRENT SCHEMA ";
		if($schema != null && $schema != "")
		{
			$setCurrentPath .= $schema . ", USER, SYSTEM PATH";
			$setCurrentSchema .= $schema;
			@db2_exec($this->dbconn, $setCurrentPath);
			@db2_exec($this->dbconn, $setCurrentSchema);
		}
		else if ($this->schema != "") {
			$setCurrentPath .= $this->schema . ", USER, SYSTEM PATH";
			$setCurrentSchema .= $this->schema;
			@db2_exec($this->dbconn, $setCurrentPath);
			@db2_exec($this->dbconn, $setCurrentSchema);
		}
	}

	function setDescription($description) {
		$this->description = $description;
		session_start();
		$_SESSION['Connections'][USE_DATABASE_CONNECTION]['description'] = $description;
		session_write_close();
	}

	/**
	 * Close the database connection.
	 */
	function close() {
		db2_close($this->dbconn); // Close the connection
	}

}
?>