<?php
/*******************************************************************************
 *  Copyright IBM Corp. 2007 All rights reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 ********************************************************************************/

class connectionManager{

	private static $connection = null;

	public static $lastErrorState = "";

	public static function getConnection($ConnectionName = null) {
		if(connectionManager::$connection === null)
		{
			connectionManager::$connection = connectionManager::retrieveConnection($ConnectionName);
		}

		return connectionManager::$connection;

	}

	public static function titleString() {
		if(connectionManager::getConnection()->connected)
		{
	        return connectionManager::connectedString();
		}
		else
		{
			return connectionManager::notConnectedString();
		}
	}

	public static function getGenericConnectedString() {
		if(connectionManager::getConnection()->connected)
		{
	        return connectionManager::genericConnectedString();
		}
		else
		{
			return connectionManager::genericNonConnectedString();
		}
	}

	public static function getClientUpdateString() {

		connectionManager::getConnection();

		return '

		<script type="text/javascript">

			updateConnectionStatus(' . (connectionManager::getConnection()->connected ? "true" : "false") . ', "' . connectionManager::titleString() . '", "' . CALLING_PAGE . '");

		</script>

		';

	}

	private static function notConnectedString(){
		return "TE Not Connected";
	}

	private static function connectedString(){

		@session_start();
		if(FORCE_CONNECTION_WITH_DEFAULT)
		{
			return DEFAULT_DB2_DATABASE_USERNAME . "@" . DEFAULT_DB2_DATABASE . "." . (DEFAULT_DB2_DATABASE_HOST_NAME != "" ? DEFAULT_DB2_DATABASE_HOST_NAME . ":" . DEFAULT_DB2_DATABASE_PORT_NUMBER : "" );
		}
		else if (USE_DATABASE_CONNECTION != null && isset($_SESSION['Connections'][USE_DATABASE_CONNECTION]))
		{
			$username = isset($_SESSION['Connections'][USE_DATABASE_CONNECTION]['username']) ? $_SESSION['Connections'][USE_DATABASE_CONNECTION]['username'] : "";
			$database = isset($_SESSION['Connections'][USE_DATABASE_CONNECTION]['database']) ? $_SESSION['Connections'][USE_DATABASE_CONNECTION]['database'] : "";
			$hostname = isset($_SESSION['Connections'][USE_DATABASE_CONNECTION]['hostname']) ? strtoupper(trim($_SESSION['Connections'][USE_DATABASE_CONNECTION]['hostname']) == "" ? "LOCALHOST" : $_SESSION['Connections'][USE_DATABASE_CONNECTION]['hostname']) : "";
			return "TE Connected: {$database} @ {$hostname} as $username";
		}
		session_write_close();
		return "";
	}

	private static function genericConnectedString() {
		return CONNECTION_SYMBOL_START . "&nbsp;" . CONNECTED . "...&nbsp;" . CONNECTION_SYMBOL_END;
	}

	private static function genericNonConnectedString() {
		return NOT_CONNECTION_SYMBOL_START . "&nbsp;" . DISCONNECTED . "...&nbsp;" . NOT_CONNECTION_SYMBOL_END;
	}

	public static function newConnection () {

		if(FORCE_CONNECTION_WITH_DEFAULT)
			return "Operation not permitted!";

		$ConnectionName = null;

		@session_start();
		if(!is_array($_SESSION['Connections']))
			$_SESSION['Connections'] = array();

		session_write_close();

		$username = getParameter('TE_DATABASE_LOGIN_USERNAME', "");
		$database = getParameter('TE_DATABASE_LOGIN_DATABASE', "");
		$hostname = getParameter('TE_DATABASE_LOGIN_HOSTNAME', "");
		$portnumber = getParameter('TE_DATABASE_LOGIN_PORTNUMBER', "");
		$password = getParameter('TE_DATABASE_LOGIN_PASSWORD', "");
		$comment = getParameter('TE_DATABASE_LOGIN_COMMENT', "");
		$usePersistentConnection = getParameter('TE_DATABASE_USE_PERSISTENT_CONNECTION', "");

		if(trim($database) == "")
		{
			connectionManager::$lastErrorState = "No database specified!";
			return false;
		}
		if(trim($username) == "")
		{
			connectionManager::$lastErrorState = "No username specified!";
			return false;
		}


		if($username != "" && $database != "")
		{
			$connectionStatus = Connection::testConnection(
					$database,
					$username,
					$password,
					$hostname,
					$portnumber,
					$usePersistentConnection
				);

			$dataServerInfo = null;

			if(is_array($connectionStatus) || is_object($connectionStatus))
			{
				$dataServerInfo = $connectionStatus;
				$connectionStatus = true;
			}

			$ConnectionName = $username . "@" . $database . ($hostname != "" ? "." . $hostname . ":" . $portnumber : "");

			if($connectionStatus === true && $database != null)
			{
				@session_start();
				$_SESSION['Connections'][$ConnectionName]['description'] = $ConnectionName;
				$_SESSION['Connections'][$ConnectionName]['database'] = $database;
				$_SESSION['Connections'][$ConnectionName]['schema'] = getParameter('TE_DATABASE_LOGIN_SCHEMA', "");
				$_SESSION['Connections'][$ConnectionName]['username'] = $username;
				$_SESSION['Connections'][$ConnectionName]['password'] = $password;
				$_SESSION['Connections'][$ConnectionName]['hostname'] = $hostname;
				$_SESSION['Connections'][$ConnectionName]['portnumber'] = $portnumber;
				$_SESSION['Connections'][$ConnectionName]['usePersistentConnection'] = $usePersistentConnection;
				$_SESSION['Connections'][$ConnectionName]['comment'] =  $comment;
				$_SESSION['Connections'][$ConnectionName]['connectionStatus'] = $connectionStatus;
				$_SESSION['Connections'][$ConnectionName]['dataServerInfo'] = $dataServerInfo;
				$_SESSION['Connections'][$ConnectionName]['authenticated'] = true;

				session_write_close();

				connectionManager::saveConnectionInStoredConnections($database, $username, $hostname, $portnumber, $comment);
				
				return $_SESSION['Connections'][$ConnectionName];

			}
			else
			{
				connectionManager::$lastErrorState = $connectionStatus;
				return false;
			}
		}
		connectionManager::$lastErrorState = "Insufficient data to form a connection.";
		return false;
	}

	public static function UpdateConnectionStatusesAllConnection()
	{
		@session_start();
		if(!isset($_SESSION['Connections']))
			$_SESSION['Connections'] = array();
		else
		{
			if(!is_array($_SESSION['Connections']))
				$_SESSION['Connections'] = array();
		}
		$connections = $_SESSION['Connections'];
		session_write_close();

		foreach($connections as $key=>$conn)
		{
			if($key == 'default' || !isset($conn['database']))
				continue;
			$connectionStatus = Connection::testConnection(
				$conn['database'],
				$conn['username'],
				$conn['password'],
				$conn['hostname'],
				$conn['portnumber']
			);

			@session_start();
			if(is_array($connectionStatus) || is_object($connectionStatus))
			{
				$_SESSION['Connections'][$key]['dataServerInfo'] = $connectionStatus;
				$_SESSION['Connections'][$key]['connectionStatus'] = true;
			}
			else
			{
				$_SESSION['Connections'][$key]['connectionStatus'] = $connectionStatus;
			}
			session_write_close();
		}

	}

	public static function newTrustedUser()
	{
		$connectionToUser = getParameter('TE_DATABASE_LOGIN_DESCRIPTION', "");
		$trustedUserName = getParameter('TRUSTED_CONTEXT_USERNAME', "");
		$trustedUserPassword = getParameter('TRUSTED_CONTEXT_PASSWORD', "");
		$conn = connectionManager::retrieveConnection($connectionToUser);

		if($conn == null) return array(false, "No connection found.");

		$result = $conn->testTrustedContextUser($trustedUserName, $trustedUserPassword);
		if($result[0] == true)
		{
			$result[1] = $trustedUserName . "|" . $connectionToUser;
			@session_start();
			if(!array_key_exists('trustedContext', $_SESSION['Connections'][$connectionToUser]))
				$_SESSION['Connections'][$connectionToUser]['trustedContext'] = array($trustedUserName => $trustedUserPassword);
			elseif(!is_array($_SESSION['Connections'][$connectionToUser]['trustedContext']))
				$_SESSION['Connections'][$connectionToUser]['trustedContext'] = array($trustedUserName => $trustedUserPassword);
			else
				$_SESSION['Connections'][$connectionToUser]['trustedContext'][$trustedUserName] = $trustedUserPassword;

			connectionManager::saveConnectionInStoredConnections($_SESSION['Connections'][$connectionToUser]['database'],
																		$_SESSION['Connections'][$connectionToUser]['username'],
																		$_SESSION['Connections'][$connectionToUser]['hostname'],
																		$_SESSION['Connections'][$connectionToUser]['portnumber'],
																		$_SESSION['Connections'][$connectionToUser]['comment'],
																		$_SESSION['Connections'][$connectionToUser]['trustedContext']);
			session_write_close();
		}
		return $result;
	}

	/**
	 * Rebuilds a Connection object from session variables.
	 * @return Connection
	 */
	private static function retrieveConnection($ConnectionName = null) {

		$trustedUsername     = "";
		$trustedUserPassword = "";

		$authenticated = "";
		$username = "";
		$password = "";
		$database = "";
		$schema = "";
		$cataloged = "";
		$hostname = "";
		$portnumber = "";
		$usePersistentConnection = USE_PERSISTENT_CONNECTION;
		$useTrustedContext = false;

		if($ConnectionName == null)
		{
			$ConnectionName = USE_DATABASE_CONNECTION;
		}

		if(strpos($ConnectionName, '|') !== false)
		{
			$ConnectionName = explode('|', $ConnectionName);
			$trustedUsername = $ConnectionName[0];
			$ConnectionName = $ConnectionName[1];
			if(array_key_exists('trustedContext', $_SESSION['Connections'][$ConnectionName]))
			{
				if(is_array($_SESSION['Connections'][$ConnectionName]['trustedContext']))
				{
					if(array_key_exists($trustedUsername, $_SESSION['Connections'][$ConnectionName]['trustedContext']))
					{
						$trustedUserPassword = $_SESSION['Connections'][$ConnectionName]['trustedContext'][$trustedUsername];
						$useTrustedContext = true;
					}
					else
					{
						return null;
					}
				}
				else
				{
					return null;
				}
			}
			else
			{
				return null;
			}
		}

		@session_start();
		if(isset($_SESSION['Connections']) && !FORCE_CONNECTION_WITH_DEFAULT)
		{
			if($ConnectionName != null && isset($_SESSION['Connections'][$ConnectionName]))
			{
				$username = isset($_SESSION['Connections'][$ConnectionName]['username']) ? $_SESSION['Connections'][$ConnectionName]['username'] : "";
				$password = isset($_SESSION['Connections'][$ConnectionName]['password']) ? $_SESSION['Connections'][$ConnectionName]['password'] : "";
				$database = isset($_SESSION['Connections'][$ConnectionName]['database']) ? $_SESSION['Connections'][$ConnectionName]['database'] : "";
				$schema = isset($_SESSION['Connections'][$ConnectionName]['schema']) ? $_SESSION['Connections'][$ConnectionName]['schema'] : "";
				$cataloged = isset($_SESSION['Connections'][$ConnectionName]['cataloged']) ? $_SESSION['Connections'][$ConnectionName]['cataloged'] : "";
				$hostname = isset($_SESSION['Connections'][$ConnectionName]['hostname']) ? $_SESSION['Connections'][$ConnectionName]['hostname'] : "";
				$portnumber = isset($_SESSION['Connections'][$ConnectionName]['portnumber']) ? $_SESSION['Connections'][$ConnectionName]['portnumber'] : "";
				$usePersistentConnection = isset($_SESSION['Connections'][$ConnectionName]['usePersistentConnection']) ? $_SESSION['Connections'][$ConnectionName]['usePersistentConnection'] : USE_PERSISTENT_CONNECTION;
			}
		}
		session_write_close();

		if(!$useTrustedContext)
		{
			return new Connection(
									$database,
									$schema,
									$username,
									$password,
									$hostname,
									$portnumber,
									$usePersistentConnection,
									$useTrustedContext
								);
		}
		else
		{
			$connection = new Connection(
									$database,
									$schema,
									$username,
									$password,
									$hostname,
									$portnumber,
									$usePersistentConnection,
									$useTrustedContext
								);
			return $connection->setTrustedContextUsers($trustedUsername, $trustedUserPassword);
		}
		return null;
	}

	public static function retrieveStoredConnections()
	{
		$connectionList = array();

		if(FORCE_CONNECTION_WITH_DEFAULT)
		{
			$discription = DEFAULT_DB2_DATABASE_USERNAME . "@" . DEFAULT_DB2_DATABASE . "." . (DEFAULT_DB2_DATABASE_HOST_NAME != "" ? DEFAULT_DB2_DATABASE_HOST_NAME . ":" . DEFAULT_DB2_DATABASE_PORT_NUMBER : "" );
			$connectionList[$discription]['comment'] = "Forced Connection";
			$connectionList[$discription]['database'] = DEFAULT_DB2_DATABASE;
			$connectionList[$discription]['hostname'] = DEFAULT_DB2_DATABASE_HOST_NAME;
			$connectionList[$discription]['portnumber'] = DEFAULT_DB2_DATABASE_PORT_NUMBER;
			$connectionList[$discription]['description'] = $discription;
			$connectionList[$discription]['username'] = DEFAULT_DB2_DATABASE_USERNAME;
			$connectionList[$discription]['password'] = "";
			$connectionList[$discription]['connectionStatus'] = Connection::testConnection(
					DEFAULT_DB2_DATABASE,
					DEFAULT_DB2_DATABASE_USERNAME,
					DEFAULT_DB2_DATABASE_PASSWORD,
					DEFAULT_DB2_DATABASE_HOST_NAME,
					DEFAULT_DB2_DATABASE_PORT_NUMBER,
					USE_PERSISTENT_CONNECTION
				);
			if(is_array($connectionList[$discription]['connectionStatus']) || is_object($connectionList[$discription]['connectionStatus']))
			{
				$connectionList[$discription]['dataServerInfo'] = $connectionList[$discription]['connectionStatus'];
				$connectionList[$discription]['connectionStatus'] = true;
			}
			$connectionList[$discription]['authenticated'] = true;
			return $connectionList;
		}

		if(CONNECTION_STORE_FILE !== false)
		{
			if(file_exists(CONNECTION_STORE_FILE))
			{
				$doc = new XMLNode();
				if($doc->loadXML(file_get_contents(CONNECTION_STORE_FILE)) !== false)
				{
 					foreach($doc->childNodes as $node)
 					{
 						$connectionArray = null;
						if(strcasecmp($node->nodeName, "RecentConnections") === 0)
						{
							$connectionArray = connectionManager::extractConnectionFromNode($node, 'name', "temp");
						}
						if(strcasecmp($node->nodeName, "SavedConnections") === 0)
						{
							$connectionArray = connectionManager::extractConnectionFromNode($node, 'name', "save");
						}
						if($connectionArray != null)
						{
							foreach($connectionArray as $connection)
							{
								$preformAutoConnect = true;
								if(isset($_SESSION['Connections'][$connection['description']]))
								{
									if(isset($_SESSION['Connections'][$connection['description']]['connectionStatus']))
										if($_SESSION['Connections'][$connection['description']]['connectionStatus'] == true)
											$preformAutoConnect = false;
								}
								if($connection['autoConnect'] == true && $preformAutoConnect)
								{

									$connectionStatus = Connection::testConnection(
											$connection['database'],
											$connection['username'],
											$connection['password'],
											$connection['hostname'],
											$connection['portnumber'],
											$connection['usePersistentConnection']
									);
									$dataServerInfo = null;

									if(is_array($connectionStatus) || is_object($connectionStatus))
									{
										$dataServerInfo = $connectionStatus;
										$connectionStatus = true;
									}
									$ConnectionName = $connection['description'];

									if($connectionStatus === true && $connection['database'] != null)
									{
										$_SESSION['Connections'][$ConnectionName]['description'] = $ConnectionName;
										$_SESSION['Connections'][$ConnectionName]['database'] = $connection['database'];
										$_SESSION['Connections'][$ConnectionName]['schema'] = $connection['schema'];
										$_SESSION['Connections'][$ConnectionName]['username'] = $connection['username'];
										$_SESSION['Connections'][$ConnectionName]['password'] = $connection['password'];
										$_SESSION['Connections'][$ConnectionName]['hostname'] = $connection['hostname'];
										$_SESSION['Connections'][$ConnectionName]['portnumber'] = $connection['portnumber'];
										$_SESSION['Connections'][$ConnectionName]['usePersistentConnection'] = $connection['usePersistentConnection'];
										$_SESSION['Connections'][$ConnectionName]['comment'] =  $connection['comment'];
										if(is_array($_SESSION['Connections'][$ConnectionName]['trustedContext']))
										{
											if(is_array($connection['trustedContext']))
											{
												foreach ($connection['trustedContext'] as $key=>$value)
													$_SESSION['Connections'][$ConnectionName]['trustedContext'][$key] = $value;
											}
										}
										else
											$_SESSION['Connections'][$ConnectionName]['trustedContext'] =  $connection['trustedContext'];
										$_SESSION['Connections'][$ConnectionName]['connectionStatus'] = $connectionStatus;
										$_SESSION['Connections'][$ConnectionName]['dataServerInfo'] = $dataServerInfo;
									}
								}
							}
							$connectionList = array_merge($connectionList, $connectionArray);
						}
 					}
				}
			}
		}

		@session_start();

		$SessionConnectionList = $_SESSION['Connections'];

		session_write_close();


		if(isset($SessionConnectionList))
		{
			foreach($SessionConnectionList as $connectionKey => $connectionInformation)
			{
				if (isSet($connectionInformation ['database'])){
					if($connectionInformation ['database'] != null)
					{
						if($connectionKey != 'default')
						{
							$connectionList[$connectionInformation['description']]['database'] = $connectionInformation ['database'];
							$connectionList[$connectionInformation['description']]['hostname'] = $connectionInformation ['hostname'];
							$connectionList[$connectionInformation['description']]['comment'] = $connectionInformation ['comment'];
							$connectionList[$connectionInformation['description']]['portnumber'] = $connectionInformation ['portnumber'];
							$connectionList[$connectionInformation['description']]['description'] = $connectionInformation ['description'];
							$connectionList[$connectionInformation['description']]['username'] = $connectionInformation ['username'];
							$connectionList[$connectionInformation['description']]['password'] = "";
							$connectionList[$connectionInformation['description']]['connectionStatus'] = $connectionInformation['connectionStatus'];
							if(array_key_exists('trustedContext', $connectionInformation))
							{
								if(is_array($_SESSION['Connections'][$connectionInformation['description']]['trustedContext']))
								{
									if(is_array($connectionInformation['trustedContext']))
									{
										foreach ($connectionInformation['trustedContext'] as $key=>$value)
										{
											$connectionList[$connectionInformation['description']]['trustedContext'][$key] = $value;
										}
									}
								}
								else
									$connectionList[$connectionInformation['description']]['trustedContext'] =  $connectionInformation['trustedContext'];
							}

							$connectionList[$connectionInformation['description']]['dataServerInfo'] = $connectionInformation['dataServerInfo'];

							$connectionList[$connectionInformation['description']]['authenticated'] = true;
							if(strtolower(USE_DATABASE_CONNECTION) == strtolower($connectionKey))
							{
								$connectionList[$connectionInformation['description']]['activeConnection'] = true;
							}
						}
					}
				}
			}
		}
		ksort($connectionList);
		return $connectionList;
	}

	private static function extractConnectionFromNode($ConnectionNode, $orderBy = 'time', $connectionType)
	{
		$connectionList = array();
		if($ConnectionNode->hasChildNodes())
		{
			foreach($ConnectionNode->childNodes as $node)
	 		{
	 			if(strcasecmp($node->nodeName, "connection") === 0)
	 			{
	 				$connection = array();
	 				$connection['connectionTag'] = null;
					$connection['connectionType'] = $connectionType;
	 				$connection['connectionStatus'] = false;
	 				$connection['authenticated'] = false;
	 				$connection['description'] = $node->getAttribute('description');
	 				$connection['time'] = $node->getAttribute('time');
	 				$connection['comment'] = $node->getChildTextContent('comment');
	 				$connection['database'] = $node->getChildTextContent('database');
	 				$connection['hostname']   = $node->getChildTextContent('hostname');
	 				$connection['portnumber']     = $node->getChildTextContent('portnumber');
	 				$connection['username'] = $node->getChildTextContent('username');
	 				$connection['password'] = $node->getChildTextContent('password');
	 				$connection['schema'] = $node->getChildTextContent('schema');
	 				$connection['usePersistentConnection'] = strtolower($node->getChildTextContent('usePersistentConnection')) == 'true' ? true : false;
	 				$connection['autoConnect'] = strtolower($node->getChildTextContent('autoConnect')) == 'true' ? true : false;
	 				if($orderBy == 'time')
	 				{
	 					$connectionList[$connection['time']] = $connection;
	 				}
	 				else
	 				{
	 					$connectionList[$connection['description']] = $connection;
	 				}
	 				$trustedContextList = $node->findChildNode('trustedContext');
	 				if($trustedContextList != null)
	 				{
	 					$connection['trustedContext'] = array();
	 					foreach($node->childNodes as $userNode)
				 		{
				 			if(strcasecmp($node->nodeName, "user") === 0)
				 			{
				 				$connection['trustedContext'][$node->getAttribute('id')] = $node->getAttribute('password');
				 			}
				 		}

	 				}

	 			}
	 		}
		}
		return $connectionList;
	}

	private static function extractValueFrom($NodeName, $node)
	{
		if($node->hasChildNodes())
		{
			foreach ($node->childNodes as $childNode)
			{
				if(strcasecmp($childNode->nodeName, $NodeName) == 0)
				{
					return trim($childNode->textContent);
				}
			}
		}
		return "";
	}

	public static function saveConnectionInStoredConnections($database, $username = "", $hostname = "", $portnumber = "", $comment = "", $trustedUserList = null)
	{
		if(CONNECTION_STORE_FILE !== false && !FORCE_CONNECTION_WITH_DEFAULT && ALLOW_CONNECTION_SAVING)
		{
			$connectionList = connectionManager::retrieveStoredConnections();
			if($connectionList != false && $username != "" && $database != "")
			{
				$description = $username . "@" . $database . ($hostname != "" ? "." . $hostname . ":" . $portnumber : "");

				$connectionList[$description]['description'] = $description;
				$connectionList[$description]['database'] = $database;
	 			$connectionList[$description]['hostname'] = $hostname;
	 			$connectionList[$description]['portnumber'] = $portnumber;
	 			$connectionList[$description]['username'] = $username;
	 			$connectionList[$description]['password'] = "";
	 			$connectionList[$description]['autoConnect'] = "";
	 			$connectionList[$description]['schema'] = "";
	 			if(!array_key_exists('trustedContext', $connectionList[$description]))
	 				$connectionList[$description]['trustedContext'] = $trustedUserList;
				else if(is_array($connectionList[$description]['trustedContext']))
				{
					if(is_array($trustedUserList))
					{
						foreach ($trustedUserList as $key=>$value)
							$connectionList[$description]['trustedContext'][$key] = $value;
					}
				}
				else
					$connectionList[$description]['trustedContext'] =  $trustedUserList;

	 			$connectionList[$description]['usePersistentConnection'] = "";
	 			$connectionList[$description]['comment'] = $comment;
	 			$connectionList[$description]['time'] = time();

				connectionManager::writeConnectionListToFile($connectionList);
			}
		}
	}

	public static function disconnectConnection($connectionName)
	{
		$connectionName = $connectionName == null ? USE_DATABASE_CONNECTION : $connectionName;
		@session_start();
		unset($_SESSION['Connections'][$connectionName]);
		session_write_close();
	}

	public static function removeConnection($connectionName)
	{
		if(!is_string($connectionName))
			return;

		connectionManager::disconnectConnection($connectionName);

		if(CONNECTION_STORE_FILE !== false && !FORCE_CONNECTION_WITH_DEFAULT && ALLOW_CONNECTION_SAVING)
		{
			$connectionList = connectionManager::retrieveStoredConnections(false);
			unset($connectionList[$connectionName]);
			connectionManager::writeConnectionListToFile($connectionList);
		}
	}

	private static function writeConnectionListToFile($connectionList)
	{
		if(CONNECTION_STORE_FILE !== false && DISABLE_CONNECTION_STORE_FILE_WRITE === false)
		{
			$file = @fopen(CONNECTION_STORE_FILE, 'w');
			if($file != false)
			{
				$XMLConnectionList = "<?xml version='1.0'?>\n";
				$XMLConnectionList .="<connectionList>\n";

				$XMLConnectionList .= "\t<SavedConnections>\n";

					foreach($connectionList as $connection)
						$XMLConnectionList .= connectionManager::convertConnectionToXMLString($connection);

				$XMLConnectionList .="\t</SavedConnections>\n";
				$XMLConnectionList .="</connectionList>\n";
				fwrite($file, $XMLConnectionList);
				fflush($file);
				fclose($file);
			}

		}
	}

	private static function convertConnectionToXMLString($connection)
	{


		if(is_array($connection))
		{
			$characterstToEncode = array('&', '"');
		    $ReplaceWith = array('&amp;','&quot;');
		    $connection['description'] = str_replace($characterstToEncode, $ReplaceWith, $connection['description']);

			$XMLString = "";

			$XMLString .= "\t\t<connection description=\"{$connection['description']}\" time=\"{$connection['time']}\">\n";

			$XMLString .= "\t\t\t<comment><![CDATA[{$connection['comment']}]]></comment>\n";

			$XMLString .= "\t\t\t<database><![CDATA[{$connection['database']}]]></database>\n";

			$XMLString .= "\t\t\t<hostname><![CDATA[{$connection['hostname']}]]></hostname>\n";

			$XMLString .= "\t\t\t<portnumber><![CDATA[{$connection['portnumber']}]]></portnumber>\n";

			$XMLString .= "\t\t\t<username><![CDATA[{$connection['username']}]]></username>\n";

			$XMLString .= "\t\t\t<password><![CDATA[{$connection['password']}]]></password>\n";

			if(isset($connection['autoConnect']))
				$XMLString .= "\t\t\t<autoConnect><![CDATA[" . ($connection['autoConnect'] ? "true" : "false") . "]]></autoConnect>\n";
			if(isset($connection['schema']))
				$XMLString .= "\t\t\t<schema><![CDATA[{$connection['schema']}]]></schema>\n";
			if(isset($connection['usePersistentConnection']))
				$XMLString .= "\t\t\t<usePersistentConnection><![CDATA[" . ($connection['usePersistentConnection'] ? "true" : "false") . "]]></usePersistentConnection>\n";

			if(isset($connection['trustedContext']))
			{
				if(is_array($connection['trustedContext']))
				{
					$XMLString .= "\t\t\t<trustedContext>\n";
					foreach($connection['trustedContext'] as $key=>$value)
					{
						$XMLString .= "\t\t\t<user id='$key' password=''/>\n";
					}
					$XMLString .= "\t\t\t</trustedContext>\n";
				}
			}


	 		$XMLString .= "\t\t</connection>\n";

	 		return $XMLString;
		}
		return "";
	}

}