<?php
/*******************************************************************************
 *  Copyright IBM Corp. 2007 All rights reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *********************************************************************************/

ArrayEncodeTableDefinition::$ROOT_XML_OBJECTS['dynamiccolumn'] = 'TableDefinitionObject_DYNAMCI_COLUMN';

function TableDefinitionObject_DYNAMCI_COLUMN(&$childNode, &$returnObject, &$displayElements, &$displayColumns) {
	
	if(!isset($returnObject["components"]['dynamiccolumn'])) $returnObject["components"]['dynamiccolumn'] = array();

	$componentAvalibility = array();
	$componentAvalibility['value'] = true;
	
	$dynamicColumn = array();
	$dynamicColumn['name'] = strtoupper($childNode->getAttribute("name", "dynamiccolumn"));
	$dynamicColumn['type'] = strtoupper($childNode->getAttribute("type", "rate"));
	$dynamicColumn['interval'] = strtoupper($childNode->getAttribute("interval", "1"));
	$dynamicColumn['column'] = strtoupper($childNode->getAttribute("column"));
	$dynamicColumn['columnSecondary'] = strtoupper($childNode->getAttribute("columnSecondary", ""));
	$dynamicColumn['dataType'] = strtoupper($childNode->getAttribute("dataType", ""));
	$dynamicColumn['title'] = $childNode->getAttribute("title", "Dynamic : " . $dynamicColumn['type']);
	$dynamicColumn['sort_enable'] = true;
	$dynamicColumn["components"] 	= array();
	$dynamicColumn['fieldType'] = 'n';
	
	foreach ($childNode->childNodes as $subNode) 								
	{
		switch (strtolower($subNode->nodeName))
		{
			case "c_presentation":
			case "type":
				$dynamicColumn['fieldType'] = trim($subNode->textContent) != "" ? strtolower(trim($subNode->textContent)) :"s";
				
				if(($dynamicColumn['fieldType'] == 'bg' || $dynamicColumn['fieldType'] == "bg_wo") && !isset($dynamicColumn['inline_histogram']))
				{
					$dynamicColumn['inline_histogram'] = array();
					$dynamicColumn['inline_histogram']['style'] = "";
					$dynamicColumn['inline_histogram']['flipColor'] = false;
					$dynamicColumn['inline_histogram']['columnName'] = trim($dynamicColumn["name"], ".");
					$componentAvalibility['inlineGraph'] = true;
				}
				break;
			case 'formatenumber':
				$formatenumber = array();
				$formatenumber['round'] = strtolower($subNode->getAttribute('round', 'false')) == 'true' ? true : false;
				$formatenumber['parseInt'] = strtolower($subNode->getAttribute('parseInt', 'false')) == 'true' ? true : false;
				$formatenumber['parseFloat'] = strtolower($subNode->getAttribute('parseFloat', 'false')) == 'true' ? true : false;
				
				$formatenumber['toExponentialVal'] = intval($subNode->getAttribute('toExponentialVal', -1));
				$formatenumber['toFixedVal'] = intval($subNode->getAttribute('toFixedVal', -1));
				$formatenumber['toPrecisionVal'] = intval($subNode->getAttribute('toPrecisionVal', -1));
				$formatenumber['toBaseVal'] = intval($subNode->getAttribute('toBaseVal', 10));
				$dynamicColumn['formatenumber'] = $formatenumber;
			case 'title':
				$dynamicColumn['title'] = trim($subNode->textContent);
				break;
			case 'currentdatareturn':
				$dynamicColumn['currentDataReturn'] = trim($subNode->textContent);
				break;
			case 'datahistoryretrieval':
				$dynamicColumn['dataHistoryRetrieval'] = trim($subNode->textContent);
				break;
			case 'datatoarchive':
				$dynamicColumn['dataToArchive'] = trim($subNode->textContent);
				break;
			case 'firstarchivereturn':
				$dynamicColumn['firstArchiveReturn'] = trim($subNode->textContent);
				break;
			case "sort_enable":
				$dynamicColumn['sort_enable'] = true;
				break;
			case "sort_disable":
				$dynamicColumn['sort_enable'] = false;
				break;
			case "graphattributes":
			case "inline_histogram":
				$colValue = 100;
				$isInline = false;
				$queryFound = false;
				foreach($subNode->childNodes as $graphValueSource)
				{
					switch(strtolower($graphValueSource->nodeName))
					{
						case "value":
							$colValue = trim($graphValueSource->textContent);
							$isInline = false;
							$queryFound = true;
							break;
						case "inrowcompare":
							$colValue = trim($graphValueSource->textContent);
							$isInline = false;
							$queryFound = true;
							break;
						case "maxfromcolumn":
							$colValue = "MAX(" . trim($graphValueSource->textContent) . ")";
							$isInline = false;
							$queryFound = true;
							break;
						case "inlinequery":
							$colValue = trim($graphValueSource->textContent);
							$isInline = true;
							$queryFound = true;
							break;
						case "filequery":
							$colValue = file_get_contents(TABLE_DEFINITION_DIRECTORY . trim($graphValueSource->textContent));
							$isInline = true;
							$queryFound = true;
							break;
					}
					if($queryFound) break;
				}
				if($isInline)
				{
					$returnObject["commonTableExpressions"][] = trim($dynamicColumn["name"], ".") . "_inline_histogram_Table (Value_to_use_for_inline_histogram) as (" .
																"select * from table(" . $colValue . ") FETCH FIRST ROW ONLY)";
					$returnObject["otherTablesToInclude"][] = trim($dynamicColumn["name"], ".") . "_inline_histogram_Table";
					$colValue = trim($dynamicColumn["name"], ".") . "_inline_histogram_Table.Value_to_use_for_inline_histogram";
					
				}
				$dynamicColumn['inline_histogram'] = array();
				$dynamicColumn['inline_histogram']['style'] = $subNode->getAttribute('style');
				$dynamicColumn['inline_histogram']['flipColor'] = str_split(strtolower($subNode->getAttribute('flipColor')));
				$dynamicColumn['inline_histogram']['flipColor'] = ($dynamicColumn['inline_histogram']['flipColor'][0] == "n" || $dynamicColumn['inline_histogram']['flipColor'][0] == 'f') ? false : true;
				$dynamicColumn['inline_histogram']['columnName'] = trim($dynamicColumn["name"], ".") . "_inline_histogram";
				$componentAvalibility['inlineGraph'] = true;
				$dataColumn = array();
				$dataColumn['name']	= trim($dynamicColumn["name"], ".") . "_inline_histogram";
				$dataColumn['sql_name']	=  $dynamicColumn['sql_name'];
				$returnObject["components"]["column"][$dataColumn['name']] = $dataColumn;
				
				
				break;
			case "c_column_mask_file":
			case "column_mask_file":
				if(!isset($dynamicColumn["mask"])) $dynamicColumn["mask"] = array();
				TableDefinitionObject_MASK( new XMLNode(null, file_get_contents(TABLE_DEFINITION_DIRECTORY . trim($subNode->textContent))), $dynamicColumn["mask"], $componentAvalibility);
				break;
			case "c_column_mask":
			case "column_mask":
				if(!isset($dynamicColumn["mask"])) $dynamicColumn["mask"] = array();
				TableDefinitionObject_MASK( $subNode, $dynamicColumn["mask"], $componentAvalibility);
				break;
			case "c_link":
			case "link":
				$dynamicColumn["components"]['link'] = trim($subNode->textContent);
				$componentAvalibility['link'] = true;
				break;
			case "c_image":
			case "image":
				$dynamicColumn["components"]['image'] = trim($subNode->textContent);
				$componentAvalibility['image'] = true;
				break;
			case "c_hide_value_if_not_masked":
				$value = strtoupper(trim($subNode->textContent));
				$dynamicColumn['hide_Non_Maked_Value'] = $value[0] == "N" || $value[0] == "F" ? false : true;
				break;
			case "hide_non_maked_values_enable":
				$dynamicColumn['hide_Non_Maked_Value'] = true;
			case "hide_non_maked_values_disable":
				$dynamicColumn['hide_Non_Maked_Value'] = false;
				break;
			case "c_mask_display_order":
				$tempValue = trim($subNode->textContent);
				$dynamicColumn['display'] = array();
				$tempValue = str_split($tempValue);
				foreach($tempValue as $value)
				{
					switch(strtolower($value)) {
						case "v":
							$dynamicColumn['display'][] = array('type'=>'component', 'value'=>'value');
							break;
						case "m":
							$dynamicColumn['display'][] = array('type'=>'component', 'value'=>'mask');
							break;
						case "r":
							$dynamicColumn['display'][] = array('type'=>'component', 'value'=>'reference');
							break;
						case "l":
							$dynamicColumn['display'][] = array('type'=>'component', 'value'=>'link');
							break;
						case "i":
							$dynamicColumn['display'][] = array('type'=>'component', 'value'=>'image');
							break;
						case "g":
							$dynamicColumn['display'][] = array('type'=>'component', 'value'=>'inlineGraph');
							break;
					}
				}
				break;
			case "display":
				$dynamicColumn['display'] = array();
				foreach($subNode->childNodes as $node)
				{
					switch(strtolower($node->nodeName)) {
						case "component":
							$dynamicColumn['display'][] = array('type'=>'component', 'value'=>$node->getAttribute("type"));
							break;
						case "text":
							$dynamicColumn['display'][] = array('type'=>'text', 'value'=>htmlspecialchars($node->textContent));
							break;
					}
				}
				break;
			default:
				$nodeName = strtolower($subNode->nodeName);
				if(preg_match("/^default_[a-zA-Z0-9]+_icon$/", $nodeName))
				{
					$temp = substr($nodeName, 8);
					$dynamicColumn["components"][$temp[1]] = trim($subNode->textContent);
				} 
				else 	if(isset(ArrayEncodeTableDefinition::$GENERIC_XML_OBJECTS[$nodeName]))
				{
					$tempFunction = ArrayEncodeTableDefinition::$GENERIC_XML_OBJECTS[$nodeName];
					$nullVaule = null;
					$tempFunction($subNode, $dynamicColumn["components"], $componentAvalibility, $nullVaule, false);
					
				}
				break;
		}
	}

	$dynamicColumn['componentAvalibility'] = array_keys($componentAvalibility);
	
	if($displayElements !== null && $displayColumns !== null)
	{
		if(isset($displayElements['dynamiccolumn']))
		{
			if(!isset($displayElements['dynamiccolumn'][$dynamicColumn['name']]))
			{
				$displayElements['dynamiccolumn'][$dynamicColumn['name']] = true;
				$aDisplayCol = array();
				$aDisplayCol['name'] = $dynamicColumn['name'];
				$aDisplayCol['type'] = 'dynamiccolumn'; 
				$aDisplayCol['isVisible'] = false; 
				$displayColumns[] = $aDisplayCol;
			}
		}
		else 
		{
			$displayElements['dynamiccolumn'] = array();
			$displayElements['dynamiccolumn'][$dynamicColumn['name']] = true;
			$aDisplayCol = array();
			$aDisplayCol['name'] = $dynamicColumn['name'];
			$aDisplayCol['type'] = 'dynamiccolumn'; 
			$aDisplayCol['isVisible'] = false; 
			$displayColumns[] = $aDisplayCol;
		}
	} else if($displayElements !== null && $displayColumns === null)
	{
		$displayElements['dynamiccolumn'] = true;
	}

	$returnObject["components"]['dynamiccolumn'][$dynamicColumn['name']] = $dynamicColumn;		
}