<?php
/*******************************************************************************
 *  Copyright IBM Corp. 2007 All rights reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *********************************************************************************/

/** Connection class */
include_once(PHP_INCLUDE_BASE_DIRECTORY . DB_CONNECTION);
include_once(PHP_INCLUDE_BASE_DIRECTORY . "JSONEncodeMenu.php");
include_once(PHP_INCLUDE_BASE_DIRECTORY . "ObjectConnectionManager.php");

/**
 * Returns login information string
 */
function authenticated() { // Return the footer html including the left side menu

	return connectionManager::getConnection()->connected;
}

function NoConnectionMessage() {
			return "No connection found please login to a database";
}

function NoConnectionMessageHTML() {
			my_header(NoConnectionMessage(), "");
			echo "<table style='width:100%;height:100%'><tr><td align='center'>" . NoConnectionMessage() . "</td></tr></table>";
			echo "<script type='text/javascript'>initiateConnectionRefresh();</script>";
			my_footer();
}

function NoConnectionMessageJSON() {
	$value = NoConnectionMessage();
	
	$returnObject = array();
	
	$returnObject['flagGeneralError'] = false;
	$returnObject['connectionError'] = false;
	$returnObject['returnCode'] = "false";
	$returnObject['returnValue'] = $value;
	echo json_encode($returnObject);
}

function callAction($ActionToCall)
{
	global $table, $metaConn, $action, $tableName, $schemaName;
	try {
  		include_once($ActionToCall);
	}catch(Exception $err){
		if(RETURN_TYPE == "JSON")
		{
			$errormsg = rawurlencode($err);
			echo <<<JSON
			{
				flagGeneralError: true,
				connectionError:false,
				returnCode: "false",
				returnValue: "$errormsg"
			}
JSON;
		}
		else 
		{
			print($err);
		}
	}
}

/**
 * Displays the common header html given a title and description
 */
function my_header($title, $description) {
	$title = trim($title);
	
	$panelID = CALLING_PANEL;
	$windowID = CALLING_WINDOW;
	$stageID = CALLING_STAGE;
	$pageID = CALLING_PAGE;
	
	$pageDescriptionText = <<<ADHOCFORM
<span id="discriptionText"><p> $description </p></span>
ADHOCFORM;

	$pageDescriptionText = rawurlencode(trim($pageDescriptionText));

	$maintext = <<<MAIN
				<div id="title">$title</div><div id='panelInformation'>$description</div>
MAIN;

		echo $maintext;
}

/**
 * Displays the common footer html given an index to the active page
 */
function my_footer() { // Return the footer html including the left side menu

	// Footer information.
	
}

/**
 * Required to transform a single quote or apostrophe
 * into two quotes for correct processing by DB2 SQL
 * @return string
 */

function addQuotes($string) {
	return str_replace("'","''",$string);
}

function generateLink($data, $panelID = CALLING_PANEL, $formList = 'null', $windowID = CALLING_WINDOW, $stageID = CALLING_STAGE, $dataType = "URL", $raiseToTop = "y")
{
	  $LINK = ' onclick=\'loadLink({type:"leaf",target:"' . $panelID . 
											'",window:"' . $windowID . 
											'",windowStage:"' . $stageID . 
											'",connectionRequired:"' . $raiseToTop . 
											'",formList:' . $formList . 
											' ,type:"' . ($dataType) .
											'",data:"' . $data .
											'"})\' ';

		return $LINK;
}

function generateRawLink($data, $panelID = CALLING_PANEL, $formList = 'null', $windowID = CALLING_WINDOW, $stageID = CALLING_STAGE, $dataType = "URL", $raiseToTop = "y")
{
	  $LINK = '({type:"leaf",target:"' . $panelID . 
							'",window:"' . $windowID . 
							'",windowStage:"' . $stageID . 
							'",connectionRequired:"' . $raiseToTop . 
							'",formList:' . $formList . 
							' ,type:"' . ($dataType) .
							'",data:"' . $data .
							'"})';

		return $LINK;
}

function processLink($link, $rowData = NULL, &$fieldLookUp = NULL)
{
	$returnString = "";
	if(isset($link['type']))
	{
		if(strcasecmp($link['type'], "html") === 0)
		{
			$returnString = urlencode(HTML_BASE_DIRECTORY . trim($link->address));
		}
		else if(strcasecmp($link['type'], "action") === 0)
		{
			if(isset($link->parameters))
			{
				$returnString = ACTION_PROCESSOR . "?" . prossessParameters($link->parameters, $rowData, $fieldLookUp);
			}
			else
			{
				$returnString = ACTION_PROCESSOR . "?";
			}
		}
		else
		{
			if(isset($link->address))
			{
				if(trim($link->address) != "")
				{
					$returnString = trim($link->address);
				}
				else
				{
					$returnString = $link['type'] . "php";
				}
			}
			else
			{
				$returnString = $link['type'] . "php";
			}

			if(isset($link->parameters))
			{
				$returnString .= "?" . prossessParameters($link->parameters, $rowData, $fieldLookUp);
			}
		}
	}
	else
	{
		$returnString = $link;
	}
	return $returnString;
}

function prossessParameters($parameters, $rowData, $fieldLookUp)
{
	$returnString = "";
	$param = (array)$parameters;//->children();

	foreach($param as $key => $value)
	{
		if(isset($value->keycolumn))
		{
			$default = isset($value->defaultvalue) ? $value->defaultvalue : "";
			$value = isset($fieldLookUp[$value->keycolumn]) ? $rowData[$fieldLookUp[$value->keycolumn]] : $default;
			$returnString.= trim($key) . "=" . trim($value) . "&";
		}
		else
		{
			if(isset($value->link))
			{
				$returnString.= trim($key) . "=" . urlencode(processLink($value->link, $rowData, $fieldLookUp)) . "&";
			}
			else
			{
				$returnString.= trim($key) . "=" . trim($value) . "&";
			}
		}
	}
	return substr($returnString, 0, strlen($returnString)-1);
}

function makeDisplayGroup($titleInfo, $contentInfo)
{
	return <<<Table

<table class="groupTable">
	<tbody>
		<tr><td class="groupTableTopLeft"></td><td class="groupTableTop"></td><td class="groupTableTopRight"></td></tr>
		<tr>
			<td class="groupTableLeft">
			</td>
			<td class="groupTableCenter">
				<div class="groupTableTitle">
					$titleInfo
				</div>
				<span class="groupTableContent">
					<table width="100%" border="0" cellspacing="0" cellpadding="0">
					$contentInfo
					</table>
				</span>
			</td>
			<td class="groupTableRight"></td>
		</tr>
		<tr><td class="groupTableBottomLeft"></td><td class="groupTableBottom"></td><td class="groupTableBottomRight"></td></tr>
	</tbody>
</table>
Table;

}

function makeDisplayContent($titleInfo, $contentInfo, $graphicInfo = null)
{
	if( $graphicInfo === null)
	{
	return <<<Table
	<tr>
		<td class="ContentTableTitle">
			$titleInfo
		</td>
		<td class="ContentTableContent">
			$contentInfo
		</td>
	</tr>
Table;
	}
	else
	{
	return <<<Table

	<tr>
		<td class="ContentTableTitle">
			<span>
				$titleInfo
			</span><br/>
			<span class="ContentTableContent">
				$contentInfo
			</span>
		</td>
		<td class="ContentTableGraphic">
			$graphicInfo
		</td>
	</tr>

Table;

	}
}


function parseXML($input)
{
	$doc = null;

	try 
	{
		$doc = new XMLNode();
		if($doc->loadXML($input) === false)
		{
			return "\n\n-- XML parsing error  --\n\n";
		}
	}
	catch (Exception $e)
	{
		return "\n\n-- XML parsing error  --\n\n";
	}
	return print_XML_NODE($doc, 0);
}

function print_XML_NODE($node, $level=0)
{
	if($node == null) return "";
	
	$return_string = "\n";
	$return_string .= print_White_Space($level);
	$return_string .= "<" . $node->nodeName;
	if(count($node->attributes) > 0)
	{
	  $return_string .= print_Attribute($node->attributes);
	}
	
	if($node->hasChildNodes())
	{
		$return_string .= ">";
		foreach($node->childNodes as $childNode)
		{
			$return_string .= print_XML_NODE($childNode, $level+1);
		}
		$return_string .= "\n";
	} else if(trim($node->textContent) != "") {
		$return_string .= ">";
		if(stripos(trim($node->textContent), "\n") === false)
		{
			$return_string .= htmlspecialchars(trim($node->textContent));
		}
		else 
		{
			$return_string .= "<![CDATA[\n" . trim($node->textContent);
			$return_string .= "\n" . print_White_Space($level) . "]]>";
		}
	}
	if(trim($node->textContent) == "" && !$node->hasChildNodes())
		$return_string .= "/>";
	else 
	{
		if($node->hasChildNodes())
			$return_string .= print_White_Space($level);
		$return_string .= "</" . $node->nodeName . ">";
	}
	
	return $return_string;
}

 function print_Attribute($attrib)
{
    $return_string = "";
    foreach($attrib as $key => $value)
    {
      $return_string .= ' ' . $key . '="' . addslashes($value) . '"';
    }
    return $return_string;
}

 function print_White_Space($number)
{
    $return_string = "";
    $i = 0;
    for(;$i<$number;$i++)
    {
        $return_string .= "\t";
    }
    return $return_string;
}

function formateTimeForDisplay($number) {
	if($number > 1 )
		return round($number, 4) . "s";
	if($number > 0.0001 )
		return round($number*1000, 4) . "ms";
	if($number > 0.0000001 )
		return round($number*1000000, 4) . "µs";
	if($number > 0.0000000001 )
		return round($number*1000000000, 4) . "ns";
}

function getParameter($name, $defaultValue = null)
{
	$parameter = isset($_GET[$name]) ? $_GET[$name] : (isset($_POST[$name]) ? $_POST[$name] : null);
	if(	$parameter != null )
	{
		if(@magic_quotes_gpc || @magic_quotes_runtime )
		{
            if(is_string($parameter))
            {
            	$parameter = stripcslashes($parameter);
            }
            else if(is_array($parameter))
            {
            	stripSlashesProcessArray($parameter);
            }
		}
	}
	else 
	{
		$parameter = $defaultValue;
	}
	return $parameter;
}

function stripSlashesProcessArray(&$parameter)
{
	if($parameter == null || !is_array($parameter)) return null;
	foreach($parameter as $key => &$value)
	{
		if(is_string($value))
		{
        	$parameter[$key] = stripcslashes($parameter[$key]);
		}
        else if(is_array($value))
        {
        	stripSlashesProcessArray($parameter[$key]);
        }
	}
}
function writeJSConstant($constant)
{
	if(is_array($constant))
	{
		foreach($constant as $constantName)
		{
			echo 'var ' . $constantName . ' = "' . constant($constantName) . "\";\n";
			echo 'GLOBAL_CONSTANTS.set("' . $constantName . '", "' . constant($constantName) . "\");\n";
		}
	}
	else if(is_string($constant))
	{
		echo 'var ' . $constant . ' = "' . constant($constant) . "\";\n";
		echo 'GLOBAL_CONSTANTS.set("' . $constant . '", "' . constant($constant) . "\");\n";
	}
}
