function QueryBuilder_buildSelect(queryBase, fetchFirst) {
	var columns = QueryBuilder_buildColumnList(queryBase);
	if(columns == "" || columns == null) return null;
	return QueryBuilder_buildWithList(queryBase) + " SELECT " + columns + " FROM " + QueryBuilder_buildFrom(queryBase) + " " + QueryBuilder_buildWhereClause(queryBase) + " " + QueryBuilder_buildOrderByClause(queryBase) + QueryBuilder_fetchFiest(fetchFirst) + " FOR READ ONLY";
}

function QueryBuilder_fetchFiest(fetchFirst) {
	if(fetchFirst == false || fetchFirst == null || fetchFirst == "") return "";
	if(Object.isNumber(fetchFirst))
	{
		return " FETCH FIRST " + fetchFirst + " ROWS ONLY";	
	}
	if(Object.isString(fetchFirst))
	{
		return fetchFirst;
	}
	else
	{
		return " FETCH FIRST ROW ONLY";	
	}
}

function QueryBuilder_buildFrom(queryBase) {

	var baseTableQuery = "";
	
	var otherTables = "";

	if(queryBase.queryType == null)
		return queryBase.baseQuery;

	var tableName = "";
	if(queryBase.tableName != "" && queryBase.tableName != null)
		tableName =" as " + queryBase.tableName;
	switch(queryBase.queryType.toLowerCase()) {
		case 'table':
			baseTableQuery = queryBase.baseQuery + " " + tableName;
			break;
		case 'inlinequery':
			baseTableQuery = "table(" + QueryBuilder_insertParameters(encodeMessage(queryBase.baseQuery, $H(queryBase.tableCallParameters)), queryBase) + ")" + tableName;
			break;
		case 'function':
			var functionInside = "";
			var parmPresent = false;
			if(queryBase.parameters != null) {
				var parmLength = queryBase.parameters.each(function (parm) {
					if(parmPresent) functionInside += ",";
					parmPresent = true;
					var value = parm.value;
					value = value != null ? value : "''";
					if(!Object.isNumber(value)) {
						value = value.replace(/[\\]/g, "\\\\").replace(/[']/g, "\\'").replace(/[\n]/g, "\\n");
						if (parm.type == "s") {
							functionInside += "'" + value + "'";
						} else {
							functionInside += value;
						}
					} else{
						functionInside += value;
					}
					
				});
			}
			baseTableQuery = "TABLE(" + queryBase.baseQuery + (functionInside != "" ? "(" + functionInside + ")" : "") + ")" + tableName;
			break;
		default:
			baseTableQuery = queryBase.baseQuery;
	}

	if(queryBase.otherTablesToInclude != null) 
	{
		if(queryBase.otherTablesToInclude.length > 0) 
		{
			queryBase.otherTablesToInclude.each(function(tableName) { otherTables += ", " + tableName; } );
		}
	}
	
	var returnedTable = "";
	var keys = $H(queryBase.components).keys();
	var keyLength = keys.length;
	var i = 0;
	
	var tableColumnRenderingModule = null;
	
	for(i=0; i<keyLength; i++)
	{
		tableColumnRenderingModule = TABLE_COLUMN_RENDERING_MODULES.get(keys[i]);
		if(tableColumnRenderingModule != null)
		{
			if(tableColumnRenderingModule.containsTablesForQuery == true)
			{
				returnedTable = "";
				returnedTable = tableColumnRenderingModule.tablesForQueryPortion(queryBase);
				returnedTable = returnedTable.replace(/(^\s*)|(\s*$)/g, '')
				if(returnedTable.length > 0)
				{
					otherTables += ", " + returnedTable;
				}
			}
			if(tableColumnRenderingModule.containsTableForJoinInQuery == true)
			{
				baseTableQuery = tableColumnRenderingModule.tableForJoinInQuery(queryBase, baseTableQuery);
			}
		}
	}
	
	return baseTableQuery + otherTables;
}

function QueryBuilder_insertParameters(SQLquery, queryBase)
{
	if(queryBase.parameters == null)
		return SQLquery;

	var parmCount = 0;
	
	var parsedFunction = "";

	var SQLqueryAsCharArray = SQLquery.split("");
	var ESCfound = false;
	
	SQLqueryAsCharArray.each(function(achar)
	{
		if(ESCfound)
		{
			ESCfound = false;
			parsedFunction += achar;
		}
		else if(achar == '\\')
		{
			ESCfound = true;
		}
		else if(achar == '?')
		{
			if(queryBase.parameters[parmCount] != null)
			{
				var parm= queryBase.parameters[parmCount];
				var name= parm.name;
				var pname = null;
				
				if(name != null)
					if(queryBase.tableCallParameters[name] != null)
						pname = queryBase.tableCallParameters[name];

				if(pname == null)
					pname = parm.value == null ? "" : parm.value;

				if (parm.type.toLowerCase() == "s") {
					parsedFunction += "'" + pname + "'";
				}
				else {
					parsedFunction += pname;
				}
			}
			parmCount++;
		}
		else 
		{
			parsedFunction += achar;
		}
	});

	return parsedFunction;
}

function QueryBuilder_buildWithList(queryBase)
{
	if(queryBase.commonTableExpressions == null) return "";

	var returnString = "";
	if(queryBase.commonTableExpressions.length > 0) 
	{
		var firstQuery = true;
		queryBase.commonTableExpressions.each(function(commonTableExpressions) { 
			if(!firstQuery) returnString += ", ";
			firstQuery = false;
			returnString += commonTableExpressions; 
		} );
	}
	var returnedWithList = "";
	
	var keys = $H(queryBase.components).keys();
	var keyLength = keys.length;
	var i = 0;
	
	var tableColumnRenderingModule = null;
	
	for(i=0; i<keyLength; i++)
	{
		tableColumnRenderingModule = TABLE_COLUMN_RENDERING_MODULES.get(keys[i]);
		if(tableColumnRenderingModule != null)
		{
			if(tableColumnRenderingModule.containsCommonTableExpressionsForQuery == true)
			{
				returnedWithList = "";
				returnedWithList = tableColumnRenderingModule.commonTableExpressionsQueryPortion(queryBase);
				returnedWithList = returnedWithList.replace(/(^\s*)|(\s*$)/g, '')
				if(returnedWithList.length > 0 && returnString.length > 0)
				{
					returnString += ", " + returnedWithList;
				}
				else if(returnedWithList.length > 0 && returnString.length == 0)
				{
					returnString = returnedWithList;
				}
			}
		}
	}
	
	return returnString != "" ? "WITH " + returnString + " " : "";
}


	
function QueryBuilder_buildOrderByClause(queryBase) {
	
	var orderBy = "";
	var parmPresent = false;
	if(queryBase.orderBy != null)
	{
		queryBase.orderBy.each(function(sortElement)
		{
			var orderByValue = sortElement.direction;
			if(orderByValue != null)
			{
				if(parmPresent) orderBy += ",";
				parmPresent = true;
				orderByValue = orderByValue.substr(0,1).toUpperCase() == "A" ? "ASC" : "DESC";
				var index = queryBase.components.column[sortElement.column];
				if(index != null)
					var index = index.sql_name;
				else
					index = sortElement.column;
				orderBy += sortElement.column + " " + orderByValue;
			}
		});
	}
	
	if(orderBy == "")
	{
		return "";
	}
	return "ORDER BY " + orderBy;
	
	
}

function QueryBuilder_buildColumnList(queryBase) {

	var columnList = "";
	var returnedColumnList = "";
	
	var keys = $H(queryBase.components).keys();
	var keyLength = keys.length;
	var i = 0;
	
	var tableColumnRenderingModule = null;
	
	for(i=0; i<keyLength; i++)
	{
		tableColumnRenderingModule = TABLE_COLUMN_RENDERING_MODULES.get(keys[i]);
		if(tableColumnRenderingModule != null)
		{
			if(tableColumnRenderingModule.containsColumnForQuery == true)
			{
				returnedColumnList = "";
				returnedColumnList = tableColumnRenderingModule.columnQueryPortion(queryBase);
				returnedColumnList = returnedColumnList.replace(/(^\s*)|(\s*$)/g, '')
				if(returnedColumnList.length > 0 && columnList.length > 0)
				{
					columnList += ", " + returnedColumnList;
				}
				else if(returnedColumnList.length > 0 && columnList.length == 0)
				{
					columnList = returnedColumnList;
				}
			}
		}
	}
	
	if(columnList.length == 0)
	{
		columnList = "*";	
	}

	return columnList;

}

function QueryBuilder_buildWhereClause(queryBase) {
	
	var whereClause = "";
	var writenItems = 0;
	
	
	var rootNode = queryBase.where;
	var nodeStack = [];
	var indexStack = [];
	var whereStack = [];
	var writenItemStack = [];
	
	var Operand = "";
	
	if(rootNode != null)
	{
		whereClause = "";
		if(rootNode.type.toLowerCase() == "group")
		{
			Operand = rootNode.Operand;
			for(var i = 0; i < rootNode.groupNodes.length || nodeStack.length != 0; i++)
			{
				if(i > rootNode.groupNodes.length)
				{
					rootNode = nodeStack.pop();
					i = indexStack.pop();
					Operand = rootNode.Operand;
					var oldWhere = whereStack.pop();
					var oldWritenItems = writenItemStack.pop();
					if(writenItems != 0)
					{
						if(writenItems > 1)
							whereClause = "(" + whereClause + ")";
							
						if(oldWritenItems > 1)
							whereClause = oldWhere + " " + Operand + " " + whereClause;
						else
							whereClause = whereClause;
						oldWritenItems++;
					}
					else
						whereClause = oldWhere;
					writenItems = oldWritenItems;
					continue;
				}
				
				if(rootNode.groupNodes[i].type.toLowerCase() == "group")
				{
					whereStack.push(whereClause);
					nodeStack.push(rootNode);
					indexStack.push(i);
					writenItemStack.push(writenItems);
					writenItems = 0;
					i = 0;
					whereClause = "";
					rootNode = rootNode.groupNodes[i];
					Operand = rootNode.Operand;
					continue;
				}
				else
				{
					if(rootNode.groupNodes[i].column != "" && rootNode.groupNodes[i].compareType != "" && (rootNode.groupNodes[i].value != "" || Object.isNumber(rootNode.groupNodes[i].value)) )
					{
						if(writenItems != 0) whereClause += " " + Operand;
						whereClause += " " + queryBase.components.column[rootNode.groupNodes[i].column].sql_name + " " + rootNode.groupNodes[i].compareType + " " + rootNode.groupNodes[i].value;
						writenItems++;
					}
				}
			
			}
		}
		else
		{
			if(rootNode.column != "" && rootNode.compareType != "" && (rootNode.value != "" || Object.isNumber(rootNode.value)) )
			{
				if(writenItems != 0) whereClause += " " + Operand;
				whereClause += " " + queryBase.components.column[rootNode.column].sql_name + " " + rootNode.compareType + " " + rootNode.value;
				writenItems++;
			}
		}
	}
	
	whereClause = whereClause.replace(/(^\s*)|(\s*$)/g, '');

	var returnedWhereList = "";
	
	var keys = $H(queryBase.components).keys();
	var keyLength = keys.length;
	var i = 0;
	
	var tableColumnRenderingModule = null;
	
	for(i=0; i<keyLength; i++)
	{
		tableColumnRenderingModule = TABLE_COLUMN_RENDERING_MODULES.get(keys[i]);
		if(tableColumnRenderingModule != null)
		{
			if(tableColumnRenderingModule.containsWhereClauseForQuery == true)
			{
				returnedWhereList = "";
				returnedWhereList = tableColumnRenderingModule.whereClauseQueryPortion(queryBase);
				returnedWhereList = returnedWhereList.replace(/(^\s*)|(\s*$)/g, '')
				if(returnedWhereList.length > 0 && whereClause.length > 0)
				{
					whereClause = "(" + whereClause + ") AND (" + returnedWhereList + ")";
				}
				else if(returnedColumnList.length > 0 && whereClause.length == 0)
				{
					whereClause = returnedWhereList;
				}
			}
		}
	}
	if(whereClause.length > 0)
	{
		whereClause = "WHERE " + whereClause;
	}

	return whereClause;
}