/*******************************************************************************
 *Copyright IBM Corp. 2007 All rights reserved.
 *
 *Licensed under the Apache License, Version 2.0 (the "License");
 *you may not use this file except in compliance with the License.
 *You may obtain a copy of the License at
 *
 *	http://www.apache.org/licenses/LICENSE-2.0
 *
 *Unless required by applicable law or agreed to in writing, software
 *distributed under the License is distributed on an "AS IS" BASIS,
 *WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *See the License for the specific language governing permissions and
 *limitations under the License.
 *********************************************************************************/
var ActiveFeeds = $H();

function reloadAllActiveFeeds() {
	ActiveFeeds.each(function(pair){
		pair.value.feedFetcher();
	});
	
}

CORE_CLIENT_ACTIONS.set("feedReader",Class.create(basePageElement, {
	initialize: function($super, callParameters) {
		$super(callParameters.uniqueID + "_FeedReader", "feedreader");
			
		this.parentStageID = callParameters.stageID;
		this.parentWindowID = callParameters.windowID;
		this.parentPanelID = callParameters.panelID;
		
		ActiveFeeds.set(this.elementName, this);
			
		var parentPanel = getPanel(this.parentStageID, this.parentWindowID, this.parentPanelID);
		parentPanel.registerNestedObject(this.elementUniqueID, this);
		
		parentPanel.refreshType = "callBack";
		parentPanel.refreshCallback = "ActiveFeeds.get('" + this.elementName + "').feedFetcher();";
		
		this.source = callParameters.source;

		this.draw();
	},
	destroy: function() {
		ActiveFeeds.unset(this.elementName);
	},

	feedFetcher: function() {
		
		var thisObject = this;
		
		POSTDATA = new Object();
		POSTDATA.uniqueID 				= this.elementUniqueID;
		POSTDATA.stageID 				= this.parentStageID;
		POSTDATA.windowID 				= this.parentWindowID;
		POSTDATA.panelID 				= this.parentPanelID;
		POSTDATA.returntype 			= 'JSON';
		POSTDATA.source				 = this.source;
		POSTDATA.action				 = "getFeedData";

		new Ajax.Request(ACTION_PROCESSOR, {
			'parameters': POSTDATA,
			onSuccess: function(transport) {
				var result = transport.responseJSON;
				
				if(result == null)
				{
					thisObject.setError("<table style='width:100%;height:100%'><tr><td align='center'><h2>An invalid JavaScript object was returned</h2></td></tr></table>");
					return;
				}
				if(result.flagGeneralError == true && result.connectionError == true)
				{
					initiateConnectionRefresh();
				}
				if(result.flagGeneralError == true || result.returnCode == "false" || result.returnCode == false)
				{
					if(Object.isString(result.returnValue))
					{
						thisObject.setError("<table style='width:100%;height:100%'><tr><td align='center'><h2>" + result.returnValue + "</h2></td></tr></table>");
						return;
					}
					else 
					{
						if(!thisObject.baseTableData.localTableDeffinition.ignoreSQLWarnings)
						{
							thisObject.setError("<table style='width:100%;height:100%'><tr><td align='center'><h2>" + result.returnValue.STMTMSG + "</h2></td></tr></table>");
							return;
						}
					}
				}
				
				if(result != null)
				{
					thisObject.FeedsDataTable = result.returnValue;
					thisObject.updateData();
				}
			},
			'onException': function(transport,exception) {
				thisObject.setError("<table style='width:100%;height:100%'><tr><td align='center'><h2>Exception while loading table data</h2>"+exception+"</td></tr></table>");
			},
			'onFailure': function(transport) {
				thisObject.setError("<table style='width:100%;height:100%'><tr><td align='center'><h2>Error loading table data</h2></td></tr></table>");
			}
		});
	},
	
	setError: function(ErrorMSG) {
		var container = $(this.elementName + "_FeedList");
		if(container != null)
			container.update("<tr><td>" + ErrorMSG + "</td></tr>");
	},
	
 	toggleDetails: function(ID)
	{					
		var detailHolder = $(this.elementName + "_" + ID);
		var signHolder = $(this.elementName + "_" + ID + "_sign");
		
		if(detailHolder != null)
		{
			if (!detailHolder.visible()) {
				detailHolder.show();
				if(signHolder != null)
					signHolder.src = 'images/minus.gif';
			}
			else {
				detailHolder.hide();
				if(signHolder != null)
					signHolder.src = 'images/plus.gif';
			}
		}
	},
	updateData: function (displayType)
	{
		var dataTable = $(this.elementName + "_FeedList");
		
		if(dataTable == null) return;
		
		if(this.FeedsDataTable == null)
		{
			dataTable.update("<tr><td align='center'>No feeds found</td></tr>");
			return;
		}
		
		var displayType = displayType != null ? displayType : 'default';
		displayType = displayType.toLowerCase()


		dataTable.update("");
				
		var FeedsBackColors = ['lightgrey', 'white'];
		var SourceColor = 0;
		var feedOutput = "";
		var sourceFeedListLength = this.FeedsDataTable.length;
		var storiesReturned = false;
		var i = 0;
		var j = 0;
		
		
		for(i = 0; i < sourceFeedListLength; i++)
		{
			if(this.FeedsDataTable[i].items === null || !Object.isArray(this.FeedsDataTable[i].items)) continue;
			var numberOfStories = this.FeedsDataTable[i].items.length;
			if(numberOfStories == 0 ) continue;
			if(this.FeedsDataTable[i].title != displayType && displayType != 'default' && displayType != 'all') continue;
			
			storiesReturned = true;

			SourceColor = (SourceColor+1)%2;
		
			dataTable.insert({bottom: "<tr style='background-color:" + FeedsBackColors[SourceColor] + "; cursor:pointer;' onclick=\"ActiveFeeds.get('" + this.elementName + "').toggleDetails('FeedList_" + i + "');\">" +
								"<td>" + "<img id='" + this.elementName + "_FeedList_"+ i +"_sign' src='images/plus.gif'>" +										
									"</td><td><b>" + (this.FeedsDataTable[i].title != null ? this.FeedsDataTable[i].title: "No Source Info found") +
									"</b></td></tr>"});

			feedOutput = "<tr style='background-color:" + FeedsBackColors[SourceColor] + ";'><td colspan=\"2\"><div id='" + this.elementName + "_FeedList_"+ i +"' style='display:none; background-color:" + FeedsBackColors[SourceColor] + ";'><table cellpadding='2' cellspacing='0' style='margin: 0px; padding: 0px; width:100%; background-color:" + FeedsBackColors[SourceColor] + ";'>";
			for(j = 0; j < numberOfStories; j++)
			{
				feedOutput += "<tr style='background-color:" + FeedsBackColors[j%2] + "; cursor:pointer;' onclick=\"ActiveFeeds.get('" + this.elementName + "').toggleDetails('feedstory_" + i + "_" + j + "');\">" +
																"<td></td>" + 
																"<td>" + "<img id='" + this.elementName + "_feedstory_" + i + "_" + j + "_sign' src='images/plus.gif'>" +
																"</td>" +
																"<td>" + (this.FeedsDataTable[i].items[j].dateDisplay != null ? this.FeedsDataTable[i].items[j].dateDisplay : "Unknown date") +
																"</td>" +
																"<td>" + (this.FeedsDataTable[i].items[j].title == null ? "no title" : this.FeedsDataTable[i].items[j].title) +
																"</td></tr>";

				feedOutput += "<tr style='background-color:" + FeedsBackColors[j%2] + ";'>" + 
							"<td></td>" + 
							"<td></td>" + 
							"<td colspan=\"2\"><div id='" + this.elementName + "_feedstory_" + i + "_" + j + "' style='display:none; background-color:" + FeedsBackColors[j%2] + ";'><table cellpadding='2' cellspacing='0' style='width:100%; background-color:" + FeedsBackColors[j%2] + ";'><tr><td>" + (this.FeedsDataTable[i].items[j].link != null ? "<a onclick='openURLonDefaultStageInIframe(\"" + this.FeedsDataTable[i].items[j].link + "\");'>" + this.FeedsDataTable[i].items[j].link +"</a>" : "" )+
							"</td></tr><tr><td><table border='2' cellpadding='2'><tr><td>" + (this.FeedsDataTable[i].items[j].description != null ? this.FeedsDataTable[i].items[j].description : "") +
							"</td></tr></table></td></tr></table></div></td></tr>";
			}
			
			feedOutput += "</table></div></td></tr>";
			dataTable.insert({bottom: feedOutput});
		}
		if(!storiesReturned)
			dataTable.update("<tr><td align='center'>No news!</td></tr>");		
						
		changeWorkArea();
	},
	draw: function()
	{
		var menu = [];
		var output = "";

		output += "<table id='" + this.elementName + "_FeedList' style='width:100%;' cellpadding='0' cellspacing='0' >"
		output += "<tr><td align='center'><img style='float:none;' src='images/loadingpage.gif'/></td></tr>";
		output += "</table>";
		
		menu.push({
			nodeType : "leaf",
			elementID : this.elementName + "_FeedManager_button",
			elementValue : "Feed Manager",
			elementAction : "onClick=\"FLOATINGPANEL_activeFloatingPanels.get('" + this.elementName + "_FeedManager').show_and_size();\";ActiveFeeds.get('" + this.elementName + "').updateData();"
		});
		
		menu.push({
			nodeType : "leaf",
			elementID : this.elementName + "_refersh_button",
			elementValue : "Refresh Now",
			elementAction : 'onclick="ActiveFeeds.get(\'' + this.elementName + '\').feedFetcher();"'
		});
		
		getPanel(this.parentStageID, this.parentWindowID, this.parentPanelID ).setContent(output, 'Feed Reader', null, null, menu);
				
		var feedManager = new floatingPanel(this.elementName + '_FeedManager', 'LINK', {'type':"ACTION", 'data':{'parameters':{'action':"feedManager"}}}, this.elementName + "_FeedManager_button", false, false);
		getPanel(this.parentStageID,this.parentWindowID,this.parentPanelID).registerNestedObject(feedManager);
		feedManager.draw();
		this.feedFetcher();
	}
}));