/*******************************************************************************
 *Copyright IBM Corp. 2007 All rights reserved.
 *
 *Licensed under the Apache License, Version 2.0 (the "License");
 *you may not use this file except in compliance with the License.
 *You may obtain a copy of the License at
 *
 *	http://www.apache.org/licenses/LICENSE-2.0
 *
 *Unless required by applicable law or agreed to in writing, software
 *distributed under the License is distributed on an "AS IS" BASIS,
 *WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *See the License for the specific language governing permissions and
 *limitations under the License.
 *********************************************************************************/


TABLE_COLUMN_RENDERING_MODULES.set("reference", {
	
	groupTitle: "References",
	
	columnCheck: function(baseTableObject, columnName) {
		var referenceObject = baseTableObject.components.reference[columnName];
		referenceObject.title = referenceObject.title == null ? "" : referenceObject.title;
		referenceObject.titleNoQuots = referenceObject.title.replace("'", "&#39;").replace('"', "&quot;");
		return true;
	},
	
	render: function(tableObject, rowToRender, referenceObject, maskingColumn) {

		maskingColumn = maskingColumn == null ? "" : maskingColumn;
		
		var icon = referenceObject.icon != null ? referenceObject.icon : "images/sout.gif";
		
		return "<img style='display:inline;float:none;' alt='&#8658;' title='" + referenceObject.titleNoQuots + "' onclick='TABLE_COLUMN_RENDERING_MODULES.get(\"reference\").load(event, \"" + tableObject.elementUniqueID + "\"," + rowToRender + ", \"" + referenceObject.name + "\", \"" + maskingColumn + "\");' class='tableAction' border='0' src='" + icon + "'>";

	},
	
	load: function(event, tableID, row, referenceName, maskingColumn) {
		
		var frameString = "detail";
		
		var tableObject = activeTables.get(tableID);
		
		if(tableObject == null) return false;
		
		var referenceObject = null;
		
		if(maskingColumn == "")
			referenceObject = tableObject.baseTableData.components.reference[referenceName];
		else
		{
			referenceObject = TABLE_COLUMN_RENDERING_MODULES.get('column').getObject("reference", maskingColumn, row, tableObject);
		}
		
		var parameters = {};
		
		switch (referenceObject.reftype.toLowerCase()) {

			case "table":
				parameters.table = referenceObject.refvalue;
				parameters.action = "list_table";
				break;
			case "displayrow":
				parameters.table = referenceObject.refvalue;
				parameters.action = "display";
				break;
			case "graph":
				parameters.table = referenceObject.refvalue;
				parameters.action = "graphYUI";
				break;
			case "action":
				parameters.action = referenceObject.refvalue;
				break;
		}
		
		referenceObject.ref.each(function(ref) {
			var column = ref.local_column_name != null ? ref.local_column_name : "";
			var key = ref.foreign_column_name;
			if (tableObject.baseTableData.resultSetIndexByColumnName[column.toUpperCase()] != null) 
			{
				column = tableObject.baseTableData.baseData[row][tableObject.baseTableData.resultSetIndexByColumnName[column.toUpperCase()]]; // And then extract its value
				parameters[key] = column;
			}
			else if(ref.value != null)
			{
				parameters[key] = ref.value;
			}

			if(ref.comparetype != null)
			{
				parameters['compare' + key] = ref.comparetype;
			}
		});

		var stageSting = tableObject.parentStageID
		var windowString = tableObject.parentWindowID
		if (referenceObject.frame)
		{
			frameString = referenceObject.frame;
		}
		
		if (referenceObject.stage)
		{
			stageSting = referenceObject.stage;
		}
		
		if (referenceObject.window)
		{
			windowString = referenceObject.window;
		}
		
		if(frameString.toLowerCase() == 'main' && windowString.toLowerCase() == '_blank')
		{
			loadPage({
				target	: windowString,
				raiseToTop:"",
				windowStage : stageSting,
				content	 : {
							type:"splitPane",
							direction:"h",
							panelA: {
								type:"panel",
								name:"main",
			 					PrimaryContainer:true,
								ContentType:"LINK",
								data:{
										type:"ACTION",
										data:{
											parameters:parameters	
										}
								}
							},
							panelB: {
								type:"panel",
								name:"detail",
								PrimaryContainer:false,
								ContentType:"RAW",
								data:""
							}
				}});
		}
		else
		{
			loadLink({
				type:"leaf",
				target: frameString,
				window: windowString,
				windowStage: stageSting,
				connectionRequired: false,
				formList: null,
				type: "LINK",
				data: {
						parameters: parameters
					}
				});
		}
			
		
			
		Event.stop(event);
		return false;
	},
	
	getDisplayClass : function(refernceObject)
	{
		return "table-Object";
	}

});