/*******************************************************************************
 *Copyright IBM Corp. 2007 All rights reserved.
 *
 *Licensed under the Apache License, Version 2.0 (the "License");
 *you may not use this file except in compliance with the License.
 *You may obtain a copy of the License at
 *
 *	http://www.apache.org/licenses/LICENSE-2.0
 *
 *Unless required by applicable law or agreed to in writing, software
 *distributed under the License is distributed on an "AS IS" BASIS,
 *WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *See the License for the specific language governing permissions and
 *limitations under the License.
 *********************************************************************************/

TABLE_MANIPULATION_MODULES.set("Core_TableOptions", {
	
	panelLeftMenuObject: function(tableObject, menuArray) {
	
		if(tableObject.baseTableData.localTableDeffinition.dataRetrievalAction != null) return menuArray;
		
		var tempElementSubNodes = [];

		if(ENABLE_VIEW_QUERY || ALLOW_DISPLAY_OF_XML)
		{
			
			if(ENABLE_VIEW_QUERY)
			{
				tempElementSubNodes.push({
					nodeType : "leaf",
					elementValue : "Query",
					elementAction : "onClick='TABLE_MANIPULATION_MODULES.get(\"Core_TableOptions\").viewQuery(\"" + tableObject.elementUniqueID + "\");'"
				});
			}
			
			
			if(ALLOW_DISPLAY_OF_XML)
			{
				tempElementSubNodes.push({
					nodeType : "leaf",
					elementValue : "XML profile",
					elementAction : "onClick='TABLE_MANIPULATION_MODULES.get(\"Core_TableOptions\").viewXML(\"" + tableObject.elementUniqueID + "\");'"
				});
				tempElementSubNodes.push({
					nodeType : "leaf",
					elementValue : "Download XML profile",
					elementAction : "onClick='TABLE_MANIPULATION_MODULES.get(\"Core_TableOptions\").downloadXML(\"" + tableObject.elementUniqueID + "\");'"
				});
			}
			if(ENABLE_VIEW_QUERY)
			{
				tempElementSubNodes.push({
						nodeType : "leaf",
						elementValue : "Profile Query",
						elementAction : "onClick='TABLE_MANIPULATION_MODULES.get(\"Core_TableOptions\").ProfileQuery(\"" + tableObject.elementUniqueID + "\");'"
				});
			}
			
			menuArray.push({
			nodeType : "branch",
			elementValue : "View",
			elementAction : '',
			elementSubNodes : tempElementSubNodes
			});
		}		
		return menuArray;
	},
	
	
	rowMouse2DownMenuObject: function(tableObject, menuArray, rowNumber) {
	
		if(tableObject.baseTableData.detailedView == true) return menuArray;
		menuArray.push({
				nodeType : "leaf",
				elementValue : "Detailed View",
				elementAction : "onClick='TABLE_MANIPULATION_MODULES.get(\"Core_TableOptions\").loadDetailedView(\"" + tableObject.elementUniqueID + "\", " + rowNumber + ");'"
		});

		return menuArray;
	},
	
	rowHeadMouse1DoubleClickAction: function(tableObject, rowNumber) {
		this.loadDetailedView(tableObject.elementUniqueID, rowNumber);
	},
	
	cellMouse2DownMenuObject: function(tableObject, menuArray, rowNumber, columnType, columnName) {
		
		if(columnType == "column")
		{
			var columnObject = tableObject.baseTableData.components[columnType][columnName];
			if(columnObject.localQueryDataType == DB2_BLOB)
			{
				menuArray.push({
					nodeType : "leaf",
					elementValue : "View Base64",
					elementAction : "onClick='TABLE_MANIPULATION_MODULES.get(\"Core_TableOptions\").displayContent(\"" + tableObject.elementUniqueID + "\",\"" + rowNumber + "\",\"" + columnName + "\")'"
				});
			}
			else if(columnObject.localQueryDataType == DB2_CLOB)
			{
				menuArray.push({
					nodeType : "leaf",
					elementValue : "View Content",
					elementAction : "onClick='TABLE_MANIPULATION_MODULES.get(\"Core_TableOptions\").displayContent(\"" + tableObject.elementUniqueID + "\",\"" + rowNumber + "\",\"" + columnName + "\")'"
				});
			}
			
			if(columnObject.localQueryDataType == DB2_BLOB || columnObject.localQueryDataType == DB2_CLOB)
			{
				menuArray.push({
					nodeType : "leaf",
					elementValue : "Render content",
					elementAction : "onClick='TABLE_MANIPULATION_MODULES.get(\"Core_TableOptions\").renderContent(\"" + tableObject.elementUniqueID + "\",\"" + rowNumber + "\",\"" + columnName + "\")'"
				});
			}
		}
		return menuArray;
	
	},
	
	viewQuery: function(tableID) {
		
		var tableObject = activeTables.get(tableID);

		miniLinkLoader({action:'ADHOC', LoadSQLData:tableObject.getQuery()});	
	},
	
	viewXML: function(tableID) {
		
		var tableObject = activeTables.get(tableID);
		
		var useConnection = null;
		
		if(tableObject.baseTableData.localTableDeffinition.useConnectWithTag != null)
		{
			useConnection = getConnectionWithTag(tableObject.baseTableData.localTableDeffinition.useConnectWithTag);
		}
		if(useConnection == null)
		{
			useConnection = ACTIVE_DATABASE_CONNECTION;
		}

		openURLonDefaultStageInIframe( DB2MC_SERVER + '/action.php?schema=' + (tableObject.schema == null ? "" : tableObject.schema) + '&table=' + (tableObject.table == null ? "" : tableObject.table) + '&action=viewXML&USE_CONNECTION=' + useConnection);
		
	},
	
	downloadXML: function(tableID) {
		
		var tableObject = activeTables.get(tableID);
		
		var useConnection = null;
		
		if(tableObject.baseTableData.localTableDeffinition.useConnectWithTag != null)
		{
			useConnection = getConnectionWithTag(tableObject.baseTableData.localTableDeffinition.useConnectWithTag);
		}
		if(useConnection == null)
		{
			useConnection = ACTIVE_DATABASE_CONNECTION;
		}

		window.open( DB2MC_SERVER + '/action.php?schema=' + (tableObject.schema == null ? "" : tableObject.schema) + '&table=' + (tableObject.table == null ? "" : tableObject.table) + '&action=viewXML&forceSave=true&USE_CONNECTION=' + useConnection);
		
	},
	
	ProfileQuery: function(tableID) {
		
		var tableObject = activeTables.get(tableID);
		
		var profileQuery = "";
		
		if(tableObject.baseTableData.queryType == null)
			profileQuery = "SELECT * FROM " + tableObject.baseTableData.baseQuery;
	
		switch(tableObject.baseTableData.queryType.toLowerCase())
		{
			case 'table':
				profileQuery = "SELECT * FROM " + tableObject.baseTableData.baseQuery;
				break;
			case 'inlinequery':
				profileQuery = tableObject.baseTableData.baseQuery;
				break;
			case 'function':
				var functionInside = "";
				var parmPresent = false;
				if(tableObject.baseTableData.parameters != null) {
					var parmLength = tableObject.baseTableData.parameters.each(function (parm) {
						if(parmPresent) functionInside += ",";
						parmPresent = true;
						var value = parm.value;
						value = value != null ? value : "''";
						if(!Object.isNumber(value)) {
							value = value.replace(/[\\]/g, "\\\\").replace(/[']/g, "\\'").replace(/[\n]/g, "\\n");
							if (parm.type == "s") {
								functionInside += "'" + value + "'";
							} else {
								functionInside += value;
							}
						} else{
							functionInside += value;
						}
						
					});
				}
				profileQuery = queryBase.baseQuery + (functionInside != "" ? "(" + functionInside + ")" : "");
				break;
		}

		miniLinkLoader({action:'ADHOC', LoadSQLData:profileQuery});	
	},
	
	displayContent: function(tableID, rowNumber, columnName) {
		
		var displayType = "RAW";
		
		var tableObject = activeTables.get(tableID);
		
		var columnObject = tableObject.baseTableData.components["column"][columnName];
		
		if(columnObject.localQueryDataIndex == null) 
		{
			columnObject.localQueryDataIndex = tableObject.baseTableData.resultSetIndexByColumnName[columnObject.name.toUpperCase()];
			columnObject.localQueryDataType = DB2_DATA_TYPE_CLASSIFICATION[tableObject.baseTableData.columnsInfo.type[columnObject.localQueryDataIndex].toLowerCase()];
			if(columnObject.localQueryDataType == null)
				columnObject.localQueryDataType = DB2_STRING;
		}
		
		var valueToDisplay = tableObject.baseTableData.baseData[rowNumber][columnObject.localQueryDataIndex];

		if(columnObject.localQueryDataType == DB2_CLOB || columnObject.localQueryDataType == DB2_STRING)
		{
			valueToDisplay = valueToDisplay.escapeHTML();
		}
		loadLink({
				type:"leaf",
				target: "_blank",
				window: "_blank",
				windowStage: tableObject.parentStageID,
				connectionRequired: false,
				formList: null,
				type: displayType,
				data: "<pre>" + valueToDisplay + "</pre>"
			});
	},
	
	renderContent: function(tableID, rowNumber, columnName) {
		
		var displayType = "RAW";
		var type = "text";
		var action = "echo";
		
		var HTMLEncoded = "false";
		
		var tableObject = activeTables.get(tableID);
		
		var columnObject = tableObject.baseTableData.components["column"][columnName];
		
		if(columnObject.localQueryDataIndex == null) 
		{
			columnObject.localQueryDataIndex = tableObject.baseTableData.resultSetIndexByColumnName[columnObject.name.toUpperCase()];
			columnObject.localQueryDataType = DB2_DATA_TYPE_CLASSIFICATION[tableObject.baseTableData.columnsInfo.type[columnObject.localQueryDataIndex].toLowerCase()];
			if(columnObject.localQueryDataType == null)
				columnObject.localQueryDataType = DB2_STRING;
		}
		
		var valueToDisplay = tableObject.baseTableData.baseData[rowNumber][columnObject.localQueryDataIndex];
		
		if(columnObject.localQueryDataType == DB2_BLOB)
		{
			type = "blob";
			action = "echoBase64";
		}
		else if(columnObject.localQueryDataType == DB2_CLOB || columnObject.localQueryDataType == DB2_STRING)
		{
			valueToDisplay = valueToDisplay.escapeHTML();
			HTMLEncoded = "true";
		}
		
		var id = getGUID();
		
		var output = '<div id="EXTERNAL_FORM_LOAD_' + id + '" style="display:none"><form id="EXTERNAL_FORM_LOAD_' + id + '_FORM';
			output += '" target="_blank" action="' + DB2MC_SERVER + "/" + ACTION_PROCESSOR + '?action=' + action + '" method="POST"><textarea name="data" >' + valueToDisplay;
			output += '</textarea><input type="hidden" name="type" value="' + type + '"/> <input type="hidden" name="HTMLEncoded" value="' + HTMLEncoded + '"/></form></div>';

		$('PageBody').insert(output);
		submiteFormToNewWindowInStage('EXTERNAL_FORM_LOAD_' + id + '_FORM',tableObject.parentStageID);
		$('EXTERNAL_FORM_LOAD_' + id).remove();
	},
	
	loadDetailedView: function(tableID, rowNumber) {
		var tableObject = activeTables.get(tableID);
		
		
		if(tableObject.baseTableData.localTableDeffinition.detailsAction != null)
		{
			var actionScriptObject = tableObject.baseTableData.localTableDeffinition.detailsAction;
		
			var blockData = $H();
			
			$H(tableObject.baseTableData.resultSetIndexByColumnName).each(function(node) {
				blockData.set(node.key,tableObject.baseTableData.baseData[rowNumber][node.value]);
			});
			
			var actionObject = actionScriptHolder.get(tableObject.baseTableData.tableName + '_' + actionScriptObject.name);
			
			if(actionObject == null)
			{
				new actionScript(tableObject.baseTableData.tableName + '_' + actionScriptObject.name, actionScriptObject , blockData, tableObject.parentStageID, tableObject.parentWindowID, tableObject.parentPanelID, tableObject.parentPageID);
				actionObject = actionScriptHolder.get(tableObject.baseTableData.tableName + '_' + actionScriptObject.name);
			}
			
			
			
			actionScriptHolder.get(tableObject.baseTableData.tableName + '_' + actionScriptObject.name).callAction(blockData, '', '', '');
		
			
		}
		else
		{
			var parameters = new Object();
			
			if(tableObject.baseTableData.localTableDeffinition.primaryKeys.length > 0)
			{
				parameters.searchObject = {
										type:"group",
										Operand: "AND",
										groupNodes: []
									}; 
				tableObject.baseTableData.localTableDeffinition.primaryKeys.each(function(columnName) {
					
					var columnObject = tableObject.baseTableData.components["column"][columnName];
					
					if(columnObject.localQueryDataIndex == null) 
					{
						columnObject.localQueryDataIndex = tableObject.baseTableData.resultSetIndexByColumnName[columnObject.name.toUpperCase()];
						columnObject.localQueryDataType = DB2_DATA_TYPE_CLASSIFICATION[tableObject.baseTableData.columnsInfo.type[columnObject.localQueryDataIndex].toLowerCase()];
						if(columnObject.localQueryDataType == null)
							columnObject.localQueryDataType = DB2_STRING;
					}
			
					var searchValue = tableObject.baseTableData.baseData[rowNumber][columnObject.localQueryDataIndex];
			
					var SearchType = "=";
			
					if(searchValue != null)
					{
						if(columnObject.localQueryDataType == DB2_STRING)
							searchValue = "'" + searchValue + "'";
					}
					else
					{
						SearchType = "is";
						searchValue = "null";
					}
					
					
					parameters.searchObject.groupNodes.push({
									type: "value",
									column: columnName,
									compareType: SearchType,
									value: searchValue
								}); 
				});
				 
			}
			else
			{
				parameters.displayRowData = tableObject.baseTableData.baseData[rowNumber];
				parameters.displayRowColumnInfo = tableObject.baseTableData.columnsInfo;
			}
			
			parameters.action = "display";
			parameters.schema = tableObject.schema;
	
			parameters.table = tableObject.table;
			
			loadLink({
				type:"leaf",
				target: "detail",
				window: tableObject.parentWindowID,
				windowStage: tableObject.parentStageID,
				connectionRequired: false,
				formList: null,
				type: "LINK",
				data: {
						parameters: parameters
					}
				});
		}	
	}
});