CREATE OR REPLACE MODULE product_package_db2@

--------------------------------------------------------------------------------
--#line 002
ALTER MODULE product_package_db2 PUBLISH PROCEDURE create_product(
--#line 002
IN p_product_name VARCHAR2(4096), 
--#line 002
IN p_category_name VARCHAR2(4096), 
--#line 002
IN p_product_price NUMBER, 
--#line 002
IN p_quantity NUMBER, 
--#line 002
OUT o_product_id NUMBER) LANGUAGE SQL@

--------------------------------------------------------------------------------
--#line 003
ALTER MODULE product_package_db2 PUBLISH PROCEDURE verify_product_availability(
--#line 003
IN p_product_id NUMBER, 
--#line 003
IN p_items_requested NUMBER, 
OUT available_yn BOOLEAN, 
--#line 004
OUT error BOOLEAN, 
--#line 004
OUT message VARCHAR2(4096)) LANGUAGE SQL@

--------------------------------------------------------------------------------
--#line 005
ALTER MODULE product_package_db2 PUBLISH PROCEDURE write_catalog(
--#line 005
OUT message VARCHAR2(4096)) LANGUAGE SQL@

--------------------------------------------------------------------------------
--#line 011
ALTER MODULE product_package_db2 DROP BODY@

--------------------------------------------------------------------------------
COMMENT ON MODULE product_package_db2 IS 'PL/SQL Package Body'@

--------------------------------------------------------------------------------
--#line 013
  ALTER MODULE product_package_db2 ADD PROCEDURE create_product(
  --#line 013
IN p_product_name VARCHAR2(4096), 
  --#line 013
IN p_category_name VARCHAR2(4096), 
  --#line 013
IN p_product_price NUMBER, 
  --#line 013
IN p_quantity NUMBER, 
  OUT o_product_id NUMBER)
  LANGUAGE SQL
    SYSIBMINTERNAL_BLOCK: BEGIN
--#line 016
      DECLARE v_category_id           NUMBER;
--#line 000
      DECLARE SYSIBMINTERNAL_ROWCOUNT INTEGER;
--#line 000
      DECLARE SYSIBMINTERNAL_NOTFOUND BOOLEAN;
--#line 020
      SELECT category_id INTO v_category_id FROM category WHERE INITCAP(category_name) = INITCAP(p_category_name);

--#line 021
      IF ((SYSIBMINTERNAL_NOTFOUND = true)) THEN
        CALL DBMS_OUTPUT.PUT_LINE('Cannot find the category name');
      ELSE
--#line 025
        INSERT INTO product VALUES(seq_product_id.NEXTVAL, v_category_id, p_product_name, p_product_price, p_quantity);
--#line 025
        GET DIAGNOSTICS SYSIBMINTERNAL_ROWCOUNT = ROW_COUNT;
--#line 000
        SET SYSIBMINTERNAL_NOTFOUND = (CASE WHEN SYSIBMINTERNAL_ROWCOUNT <= 0 THEN true ELSE false END);
--#line 026
        SELECT seq_product_id.CURRVAL INTO o_product_id FROM dual;
        CALL DBMS_OUTPUT.PUT_LINE('SUCCESS: Product ' || p_product_name || ' was added to our warehouse with new id ' || o_product_id);
      END IF;

    END@



--------------------------------------------------------------------------------
--#line 033
  ALTER MODULE product_package_db2 ADD PROCEDURE verify_product_availability(
  --#line 033
IN p_product_id NUMBER, 
  --#line 033
IN p_items_requested NUMBER, 
  OUT available_yn BOOLEAN, 
  --#line 034
OUT error BOOLEAN, 
  --#line 034
OUT message VARCHAR2(4096))
  LANGUAGE SQL
    SYSIBMINTERNAL_BLOCK: BEGIN
--#line 037
      DECLARE c_verify_product CURSOR CONSTANT (CURSOR FOR SELECT inventory_quantity FROM product WHERE product_id = p_product_id);
--#line 039
      DECLARE v_inventory_quantity NUMBER DEFAULT 0;
--#line 042
      SET available_yn = FALSE;
      SET error = FALSE;
      SET message = '';

--#line 045
      IF (NOT c_verify_product IS OPEN) THEN
        OPEN c_verify_product;
      END IF;


--#line 049
      SYSIBMINTERNAL_00000001: LOOP
        FETCH c_verify_product INTO v_inventory_quantity;
        IF c_verify_product IS NOT FOUND THEN LEAVE SYSIBMINTERNAL_00000001; END IF;
      END LOOP SYSIBMINTERNAL_00000001;


--#line 054
      IF (CURSOR_ROWCOUNT(c_verify_product) <> 1) THEN
        SET error = TRUE;
        SET message = 'Invalid product_id';
      END IF;

--#line 058
      CLOSE c_verify_product ;

      IF (v_inventory_quantity >= p_items_requested) THEN
        SET available_yn = TRUE;
      END IF;

    END@



--------------------------------------------------------------------------------
--#line 068
  ALTER MODULE product_package_db2 ADD PROCEDURE write_catalog(
  --#line 068
OUT message VARCHAR2(4096))
  LANGUAGE SQL
    SYSIBMINTERNAL_BLOCK: BEGIN
--#line 069
      DECLARE v_filehandle            UTL_FILE.FILE_TYPE;
      DECLARE v_filename              VARCHAR2(100) DEFAULT 'catalog.out';
      DECLARE v_temp_line             VARCHAR2(100);
--#line 000
      DECLARE SQLSTATE                CHAR(5) DEFAULT '00000';
--#line 000
      DECLARE SQLCODE                 INTEGER DEFAULT 0;
--#line 000
      DECLARE SYSIBMINTERNAL_SQLCODE  INTEGER DEFAULT 0;
--#line 000
      DECLARE SYSIBMINTERNAL_SQLSTATE CHAR(5) DEFAULT '00000';
--#line 000
      DECLARE SYSIBMINTERNAL_SQLERRM  VARCHAR(500);
--#line 073
      SET message = '';
      CALL UTL_DIR.CREATE_DIRECTORY('mydir1', 'C:\\');
      SET v_filehandle = UTL_FILE.FOPEN('mydir1', v_filename, 'w');

--#line 076
      FOR i AS
        SELECT level, category_name FROM category START WITH category_name = 'Main' CONNECT BY PRIOR category_name = category_parent_name
      DO
--#line 080
        CALL UTL_FILE.PUT_LINE(v_filehandle, i.level || LPAD(' ', 4 * i.level - 1) || i.category_name);
      END FOR;

--#line 082
      CALL UTL_FILE.FCLOSE(v_filehandle);
      BEGIN
--#line 091
        DECLARE EXIT HANDLER FOR SQLSTATE '02000'
          BEGIN
--#line 000
            GET DIAGNOSTICS EXCEPTION 1 SYSIBMINTERNAL_SQLERRM = MESSAGE_TEXT;
--#line 000
            VALUES(SQLCODE, SQLSTATE) INTO SYSIBMINTERNAL_SQLCODE, SYSIBMINTERNAL_SQLSTATE;
--#line 092
            -- NULL;
          END;
--#line 085
        SET v_filehandle = UTL_FILE.FOPEN('mydir1', v_filename, 'r');

--#line 086
        LOOP
          CALL UTL_FILE.GET_LINE(v_filehandle, v_temp_line);
          SET message = message || chr(10) || v_temp_line;
        END LOOP;

      END;
--#line 095
      CALL UTL_DIR.DROP_DIRECTORY('mydir1');
    END@




CREATE OR REPLACE MODULE customer_package_db2@

--------------------------------------------------------------------------------
--#line 003
ALTER MODULE customer_package_db2 PUBLISH TYPE customer_record AS ROW 
(
  customer_id ANCHOR TO customer.customer_id,
  first_name ANCHOR TO customer.first_name,
  last_name ANCHOR TO customer.last_name,
  email ANCHOR TO customer.email,
  phone_number ANCHOR TO customer.phone_number,
  birth_date ANCHOR TO customer.birth_date

)@

--------------------------------------------------------------------------------
--#line 004
ALTER MODULE customer_package_db2 PUBLISH TYPE search_refcursor AS  CURSOR@

--------------------------------------------------------------------------------
--#line 005
ALTER MODULE customer_package_db2 PUBLISH TYPE search_criteria AS VARCHAR2(200) ARRAY[VARCHAR(20)]@

--------------------------------------------------------------------------------
--#line 007
ALTER MODULE customer_package_db2 PUBLISH FUNCTION search_customer_records(
--#line 007
p_search_criteria SEARCH_CRITERIA) RETURNS search_refcursor LANGUAGE SQL @

--------------------------------------------------------------------------------
--#line 009
ALTER MODULE customer_package_db2 PUBLISH PROCEDURE create_customer(
--#line 009
IN p_first_name ANCHOR TO customer.first_name, 
--#line 009
IN p_last_name ANCHOR TO customer.last_name, 
--#line 009
IN p_email ANCHOR TO customer.email, 
--#line 009
IN p_phone_number ANCHOR TO customer.phone_number, 
--#line 009
IN p_birth_date DATE, 
--#line 009
OUT customer_id ANCHOR TO customer.customer_id, 
--#line 009
OUT customer_exists BOOLEAN) LANGUAGE SQL@

--------------------------------------------------------------------------------
--#line 010
ALTER MODULE customer_package_db2 PUBLISH PROCEDURE get_customer(
--#line 010
IN p_customer_id ANCHOR TO customer.customer_id, 
--#line 010
OUT customer_out customer_record) LANGUAGE SQL@

--------------------------------------------------------------------------------
--#line 011
ALTER MODULE customer_package_db2 PUBLISH PROCEDURE generate_promotion(
--#line 011
IN promotion_type VARCHAR2(4096), 
--#line 011
IN promotion_output VARCHAR2(4096), 
--#line 011
OUT output VARCHAR2(4096)) LANGUAGE SQL@

--------------------------------------------------------------------------------
--#line 017
ALTER MODULE customer_package_db2 DROP BODY@

--------------------------------------------------------------------------------
COMMENT ON MODULE customer_package_db2 IS 'PL/SQL Package Body'@

--------------------------------------------------------------------------------
--#line 019
  ALTER MODULE customer_package_db2 ADD PROCEDURE create_customer(
  --#line 019
IN p_first_name ANCHOR TO customer.first_name, 
  --#line 019
IN p_last_name ANCHOR TO customer.last_name, 
  --#line 019
IN p_email ANCHOR TO customer.email, 
  --#line 019
IN p_phone_number ANCHOR TO customer.phone_number, 
  --#line 019
IN p_birth_date DATE, 
  --#line 019
OUT customer_id ANCHOR TO customer.customer_id, 
  --#line 019
OUT customer_exists BOOLEAN)
  LANGUAGE SQL
    SYSIBMINTERNAL_BLOCK: BEGIN
--#line 022
      DECLARE v_customer_rec    ANCHOR TO ROW customer;
      DECLARE v_customer_id     ANCHOR TO customer.customer_id;
--#line 025
      DECLARE c_customer_exists CURSOR CONSTANT (CURSOR FOR SELECT * FROM customer WHERE UPPER(first_name) = UPPER(p_first_name) and UPPER(last_name) = UPPER(p_last_name) and birth_date = p_birth_date);
--#line 028
      SET customer_exists = TRUE;
      OPEN c_customer_exists;
      FETCH c_customer_exists INTO v_customer_rec;

--#line 031
      IF (c_customer_exists IS NOT FOUND) THEN
        SET customer_exists = FALSE;
        BEGIN
--#line 000
          DECLARE SYSIBMINTERNAL_STMT_TEXT VARCHAR(2048);
--#line 000
          SET SYSIBMINTERNAL_STMT_TEXT = 'INSERT INTO customer VALUES( ' || seq_customer_id.NEXTVAL || ', INITCAP(''' || p_first_name || '''), INITCAP(''' || p_last_name || '''), ''' || p_email || ''',''' || p_phone_number || ''', ''' || p_birth_date || ''',''' || sysdate || ''')';
--#line 034
          EXECUTE IMMEDIATE SYSIBMINTERNAL_STMT_TEXT;
        END;
--#line 035
        SELECT seq_customer_id.CURRVAL INTO v_customer_id FROM dual;
        CALL DBMS_OUTPUT.PUT_LINE('SUCCESS: Customer "' || p_first_name || ' ' || p_last_name || '" was created with id ' || v_customer_id);
      ELSE
        CALL DBMS_OUTPUT.PUT_LINE('FAILURE: Customer "' || p_first_name || ' ' || p_last_name || '" already registered with id ' || v_customer_rec.customer_id);
      END IF;

    END@



--------------------------------------------------------------------------------
--#line 043
  ALTER MODULE customer_package_db2 ADD FUNCTION search_customer_records(
  --#line 043
p_search_criteria SEARCH_CRITERIA)
  RETURNS SEARCH_REFCURSOR
  LANGUAGE SQL
    SYSIBMINTERNAL_BLOCK: BEGIN
--#line 044
      DECLARE refcursor_out   SEARCH_REFCURSOR;
      DECLARE search_argument VARCHAR2(20);
      DECLARE search_value    VARCHAR2(200);
      DECLARE where_clause    VARCHAR2(300) DEFAULT '';
      DECLARE stmt            VARCHAR2(300);

--#line 051
      IF (p_search_criteria.COUNT > 0) THEN
        SET where_clause = ' WHERE ';
      END IF;

      BEGIN
--#line 054
        DECLARE i                         INTEGER DEFAULT 1;
--#line 054
        DECLARE SYSIBMINTERNAL_LOOP_LIMIT INTEGER;
--#line 054
        SET SYSIBMINTERNAL_LOOP_LIMIT = p_search_criteria.COUNT;

--#line 054
        SYSIBMINTERNAL_00000001: WHILE i <= SYSIBMINTERNAL_LOOP_LIMIT DO

--#line 055
          IF i = 1 THEN
            SET search_argument = p_search_criteria.FIRST;
            SET search_value = p_search_criteria(search_argument);
          ELSE

--#line 059
            IF (p_search_criteria.NEXT(search_argument) IS NOT NULL) THEN
              SET search_argument = p_search_criteria.NEXT(search_argument);
              SET search_value = p_search_criteria(search_argument);
            ELSE
              LEAVE SYSIBMINTERNAL_00000001;
            END IF;

          END IF;


--#line 067
          CASE search_argument
            WHEN 'Last Name' THEN
              SET where_clause = where_clause || ' last_name IN' || search_value;
            WHEN 'Birthday' THEN
              SET where_clause = where_clause || ' birth_date IN' || search_value;
          END CASE;

--#line 000
          SET i = i + 1;
        END WHILE;

      END;
--#line 074
      SET stmt = 'SELECT * FROM customer ' || where_clause;
      SET refcursor_out = CURSOR FOR  SYSIBMINTERNAL_00000002;
--#line 075
      PREPARE SYSIBMINTERNAL_00000002 FROM stmt;
--#line 075
      OPEN refcursor_out;
      RETURN refcursor_out;
    END@



--------------------------------------------------------------------------------
--#line 079
  ALTER MODULE customer_package_db2 ADD PROCEDURE generate_promotion(
  --#line 079
IN promotion_type VARCHAR2(4096), 
  --#line 079
IN promotion_output VARCHAR2(4096), 
  --#line 079
OUT output VARCHAR2(4096))
  LANGUAGE SQL
    SYSIBMINTERNAL_BLOCK: BEGIN
--#line 080
      DECLARE promotion_search_criteria SEARCH_CRITERIA;
      DECLARE c_search_results          SEARCH_REFCURSOR;
      DECLARE search_results            ANCHOR TO ROW customer;

--#line 085
      IF (promotion_type = 'Birthday Month') THEN
        SET output = 'Search results for Birthday Promotion' || chr(10);
        SET promotion_search_criteria('Birthday') = '(SELECT birth_date FROM customer WHERE MOD(MONTHS_BETWEEN(sysdate, birth_date),2)=0)';
      ELSEIF (promotion_type = 'Lucky number 13') THEN
        SET output = 'Search results for Lucky number 13 Promotion' || chr(10);
        SET promotion_search_criteria('Last Name') = '(SELECT last_name FROM customer WHERE MOD(ROWNUM,13)=0 ORDER BY sysfun.rand())';
      END IF;

--#line 094
      SET c_search_results = search_customer_records(promotion_search_criteria);
      SET output = output || '------------------------------------------' || chr(10);

--#line 096
      SYSIBMINTERNAL_00000003: LOOP
        FETCH c_search_results INTO search_results;
        IF (CURSOR_ROWCOUNT(c_search_results) > 100) OR(c_search_results IS NOT FOUND) THEN LEAVE SYSIBMINTERNAL_00000003; END IF;
        SET output = output || search_results.first_name || ',' || search_results.last_name || ' : ' || search_results.phone_number || ', ' || search_results.email;
      END LOOP SYSIBMINTERNAL_00000003;

    END@



--------------------------------------------------------------------------------
--#line 104
  ALTER MODULE customer_package_db2 ADD PROCEDURE get_customer(
  --#line 104
IN p_customer_id ANCHOR TO customer.customer_id, 
  --#line 104
OUT customer_out customer_record)
  LANGUAGE SQL
    SYSIBMINTERNAL_BLOCK: BEGIN
--#line 105
      DECLARE c_get_customer CURSOR CONSTANT (CURSOR FOR SELECT customer_id, first_name, last_name, email, phone_number, birth_date FROM customer WHERE customer_id = p_customer_id);
--#line 000
      DECLARE SQLSTATE                CHAR(5) DEFAULT '00000';
--#line 000
      DECLARE SQLCODE                 INTEGER DEFAULT 0;
--#line 000
      DECLARE SYSIBMINTERNAL_SQLCODE  INTEGER DEFAULT 0;
--#line 000
      DECLARE SYSIBMINTERNAL_SQLSTATE CHAR(5) DEFAULT '00000';
--#line 000
      DECLARE SYSIBMINTERNAL_SQLERRM  VARCHAR(500);
--#line 115
      DECLARE EXIT HANDLER FOR SQLEXCEPTION
        BEGIN
--#line 000
          GET DIAGNOSTICS EXCEPTION 1 SYSIBMINTERNAL_SQLERRM = MESSAGE_TEXT;
--#line 000
          VALUES(SQLCODE, SQLSTATE) INTO SYSIBMINTERNAL_SQLCODE, SYSIBMINTERNAL_SQLSTATE;
--#line 116
          CALL DBMS_OUTPUT.PUT_LINE('SQLCODE: ' || SYSIBMINTERNAL_SQLCODE);
          CALL DBMS_OUTPUT.PUT_LINE('SQLERRM: ' || SYSIBMINTERNAL_SQLERRM);
          RESIGNAL;
        END;
--#line 110
      OPEN c_get_customer;
      FETCH c_get_customer INTO customer_out;
      CLOSE c_get_customer ;
    END@



CREATE OR REPLACE MODULE order_package_db2@

--------------------------------------------------------------------------------
--#line 003
ALTER MODULE order_package_db2 PUBLISH TYPE shopping_cart_item AS ROW 
(
  product_id ANCHOR TO shopping_cart.product_id,
  quantity ANCHOR TO shopping_cart.product_quantity

)@

--------------------------------------------------------------------------------
--#line 005
ALTER MODULE order_package_db2 PUBLISH TYPE shopping_cart_product AS ANCHOR TO shopping_cart.product_id ARRAY[10]@

--------------------------------------------------------------------------------
--#line 006
ALTER MODULE order_package_db2 PUBLISH TYPE shopping_cart_quantity AS ANCHOR TO shopping_cart.product_quantity ARRAY[10]@

--------------------------------------------------------------------------------
--#line 008
ALTER MODULE order_package_db2 PUBLISH PROCEDURE add_item_to_shopping_cart(
--#line 008
IN p_product_id ANCHOR TO shopping_cart.product_id, 
--#line 008
IN p_product_quantity ANCHOR TO shopping_cart.product_quantity) LANGUAGE SQL@

--------------------------------------------------------------------------------
--#line 009
ALTER MODULE order_package_db2 PUBLISH PROCEDURE create_order(
--#line 009
IN p_customer_id ANCHOR TO customer.customer_id, 
--#line 009
OUT o_order_id ANCHOR TO orders.order_id) LANGUAGE SQL@

--------------------------------------------------------------------------------
--#line 010
ALTER MODULE order_package_db2 PUBLISH PROCEDURE print_order(
--#line 010
IN p_order_id ANCHOR TO orders.order_id) LANGUAGE SQL@

--------------------------------------------------------------------------------
--#line 014
ALTER MODULE order_package_db2 DROP BODY@

--------------------------------------------------------------------------------
COMMENT ON MODULE order_package_db2 IS 'PL/SQL Package Body'@

--------------------------------------------------------------------------------
--#line 016
  ALTER MODULE order_package_db2 ADD PROCEDURE add_item_to_shopping_cart(
  --#line 016
IN p_product_id ANCHOR TO shopping_cart.product_id, 
  --#line 016
IN p_product_quantity ANCHOR TO shopping_cart.product_quantity)
  LANGUAGE SQL
    SYSIBMINTERNAL_BLOCK: BEGIN
--#line 018
      DECLARE v_total_quantity        NUMBER;
      DECLARE product_exists_in_cart  BOOLEAN;
      DECLARE product_available_yn    BOOLEAN;
      DECLARE err                     BOOLEAN;
      DECLARE message                 VARCHAR2(100);
      DECLARE test_existance CURSOR CONSTANT (CURSOR FOR SELECT product_quantity FROM shopping_cart WHERE product_id = p_product_id);
--#line 000
      DECLARE SQLSTATE                CHAR(5) DEFAULT '00000';
--#line 000
      DECLARE SQLCODE                 INTEGER DEFAULT 0;
--#line 000
      DECLARE SYSIBMINTERNAL_SQLCODE  INTEGER DEFAULT 0;
--#line 000
      DECLARE SYSIBMINTERNAL_SQLSTATE CHAR(5) DEFAULT '00000';
--#line 000
      DECLARE SYSIBMINTERNAL_SQLERRM  VARCHAR(500);
--#line 047
      DECLARE EXIT HANDLER FOR SQLEXCEPTION
        BEGIN
--#line 000
          GET DIAGNOSTICS EXCEPTION 1 SYSIBMINTERNAL_SQLERRM = MESSAGE_TEXT;
--#line 000
          VALUES(SQLCODE, SQLSTATE) INTO SYSIBMINTERNAL_SQLCODE, SYSIBMINTERNAL_SQLSTATE;
--#line 048
          CALL DBMS_OUTPUT.PUT_LINE('SQLCODE: ' || SYSIBMINTERNAL_SQLCODE);
          CALL DBMS_OUTPUT.PUT_LINE('SQLERRM: ' || SYSIBMINTERNAL_SQLERRM);
        END;
--#line 018
      SET v_total_quantity = p_product_quantity;
      SET product_exists_in_cart = FALSE;
      SET product_available_yn = FALSE;
--#line 025
      OPEN test_existance;
      FETCH test_existance INTO v_total_quantity;

--#line 027
      IF (test_existance IS FOUND) THEN
        SET product_exists_in_cart = TRUE;
        SET v_total_quantity = v_total_quantity + p_product_quantity;
      ELSE
        SET v_total_quantity = p_product_quantity;
      END IF;

--#line 036
      CALL product_package.verify_product_availability(p_product_id, v_total_quantity, product_available_yn, err, message);

--#line 037
      IF (product_available_yn = TRUE) THEN

--#line 038
        IF (product_exists_in_cart = TRUE) THEN
          UPDATE shopping_cart SET product_quantity = v_total_quantity;
        ELSE
          INSERT INTO shopping_cart VALUES(p_product_id, v_total_quantity);
        END IF;

      ELSE
--#line 044
        CALL DBMS_OUTPUT.PUT_LINE('We do not have ' || v_total_quantity || ' items in our warehouse');
      END IF;

    END@



--------------------------------------------------------------------------------
--#line 053
  ALTER MODULE order_package_db2 ADD PROCEDURE create_order(
  --#line 053
IN p_customer_id ANCHOR TO customer.customer_id, 
  --#line 053
OUT o_order_id ANCHOR TO orders.order_id)
  LANGUAGE SQL
    SYSIBMINTERNAL_BLOCK: BEGIN
--#line 055
      DECLARE v_shopping_cart_product  SHOPPING_CART_PRODUCT;
      DECLARE v_shopping_cart_quantity SHOPPING_CART_QUANTITY;
      DECLARE c_get_shopping_cart CURSOR CONSTANT (CURSOR FOR SELECT product_id, product_quantity FROM shopping_cart);
      DECLARE i                        INTEGER DEFAULT 1;
      DECLARE v_total_price            ANCHOR TO orders.total_price DEFAULT 0;
      DECLARE v_product_price          ANCHOR TO product.product_price;
      DECLARE order_rec                ANCHOR TO ROW orders;
--#line 063
      SET o_order_id = 0;
      BEGIN
--#line 066
        DECLARE shopping_cart_rec ANCHOR TO ROW c_get_shopping_cart;
--#line 066
        OPEN c_get_shopping_cart;

--#line 066
        SYSIBMINTERNAL_00000001: LOOP
--#line 066
          FETCH c_get_shopping_cart INTO shopping_cart_rec;
--#line 066
          IF c_get_shopping_cart IS NOT FOUND THEN LEAVE SYSIBMINTERNAL_00000001; END IF;
          SET v_shopping_cart_product(i) = shopping_cart_rec.product_id;
          SET v_shopping_cart_quantity(i) = shopping_cart_rec.product_quantity;
          SET i = i + 1;

--#line 070
          IF (i = 11) THEN
            CALL DBMS_OUTPUT.PUT_LINE('Shopping cart contains more than 10 items. Only first 10 items will be part of your order');
            LEAVE SYSIBMINTERNAL_00000001;
          END IF;

        END LOOP SYSIBMINTERNAL_00000001;

--#line 066
        CLOSE c_get_shopping_cart ;
      END;

--#line 077
      IF (i < 1) THEN
        CALL DBMS_OUTPUT.PUT_LINE('You need to have at least 1 product in your shopping cart');
      ELSE
        INSERT INTO orders VALUES(seq_order_id.NEXTVAL, p_customer_id, sysdate, sysdate + 3.5, 0, 'PROCESSING');
        SELECT seq_order_id.CURRVAL INTO o_order_id FROM dual;
        BEGIN
--#line 084
          DECLARE k                         INTEGER DEFAULT 1;
--#line 084
          DECLARE SYSIBMINTERNAL_LOOP_LIMIT INTEGER;
--#line 084
          SET SYSIBMINTERNAL_LOOP_LIMIT = v_shopping_cart_product.COUNT;

--#line 084
          WHILE k <= SYSIBMINTERNAL_LOOP_LIMIT DO
            SELECT product_price INTO v_product_price FROM product WHERE product_id = v_shopping_cart_product(k);
            SET v_total_price = v_total_price + v_product_price * v_shopping_cart_quantity(k);
            INSERT INTO order_details VALUES(o_order_id, v_shopping_cart_product(k), v_shopping_cart_quantity(k));
            UPDATE product SET inventory_quantity = inventory_quantity - v_shopping_cart_quantity(k) WHERE product_id = v_shopping_cart_product(k);
--#line 000
            SET k = k + 1;
          END WHILE;

        END;
--#line 091
        UPDATE orders SET total_price = v_total_price WHERE order_id = o_order_id;
      END IF;

    END@



--------------------------------------------------------------------------------
--#line 096
  ALTER MODULE order_package_db2 ADD PROCEDURE print_order(
  --#line 096
IN p_order_id ANCHOR TO orders.order_id)
  LANGUAGE SQL
    SYSIBMINTERNAL_BLOCK: BEGIN
--#line 097
      DECLARE order_rec    ANCHOR TO ROW orders;
      DECLARE customer_rec customer_package_db2.customer_record;
--#line 100
      CALL DBMS_OUTPUT.PUT_LINE('Order : ' || p_order_id);
      CALL DBMS_OUTPUT.PUT_LINE('--------------------------------------------------------');
      SELECT * INTO order_rec FROM orders WHERE order_id = p_order_id;
--#line 104
      CALL customer_package_db2.get_customer(order_rec.customer_id, customer_rec);
      CALL DBMS_OUTPUT.PUT_LINE('Customer           : ' || customer_rec.first_name || ', ' || customer_rec.last_name);
      CALL DBMS_OUTPUT.PUT_LINE('Order creation     : ' || TO_CHAR(order_rec.creation_time, 'MM-DD-YYYY'));
      CALL DBMS_OUTPUT.PUT_LINE('Estimated Delivery : ' || TO_CHAR(order_rec.estimated_delivery_time, 'MM-DD-YYYY'));
      CALL DBMS_OUTPUT.PUT_LINE('Status             : ' || DECODE(order_rec.order_status, 'D', 'Delivered', 'Shipped'));
      CALL DBMS_OUTPUT.PUT_LINE('Total price        : ' || TO_CHAR(order_rec.total_price, '$999,999.99'));
      CALL DBMS_OUTPUT.PUT_LINE('--------------------------------------------------------');
      CALL DBMS_OUTPUT.PUT_LINE('Products : ');

--#line 114
      FOR i AS
        SELECT product_name, product_quantity FROM order_details o, product p WHERE o.product_id = p.product_id AND order_id = p_order_id
      DO
--#line 115
        CALL DBMS_OUTPUT.PUT_LINE('          ' || i.product_name || ' (' || i.product_quantity || ' pcs)');
      END FOR;

    END@



