-- Create table enabled for compression and populate with data

CREATE TABLE ?SCHEMA?.SUBSCRIBER_RATED_USAGE_COMPRESS  (
		  OUT_ROAMING_IND 		SMALLINT ,
                  OUT_ROAMING_NW_OP_KEY 	INTEGER ,
                  EVENT_START_DT 		DATE ,
                  EVENT_START_TIME 		TIME ,
                  EVENT_DURATION 		INTEGER ,
                  CORE_ACC_CHARGE_AMT 	DECIMAL(10,2) ,
                  CC_NUM 			VARCHAR(21) ,
                  EVENT_TYPE_KEY 		SMALLINT ,
                  CDR_ID_KEY 			VARCHAR(75) ,
                  EVENT_TYPE_CLSF_KEY 	SMALLINT ,
                  SUBSCRIBER_CIRCLE_ID 	SMALLINT ,
                  SUBSCRIBER_MSISDN 	BIGINT ,
                  CALL_PULSE_30 		INTEGER ,
                  CALL_PULSE_60 		INTEGER ,
                  FORWARD_TO_NUM 		BIGINT ,
                  FIRST_CELLSITE 		VARCHAR(21) ,
                  SOURCE_DESTINATION_NW_OP_KEY 	INTEGER ,
                  EVENT_DIR 			SMALLINT ,
                  TRF_PLAN_KEY 		VARCHAR(21) )
                  DISTRIBUTE BY HASH(SUBSCRIBER_MSISDN)		  
                    ORGANIZE BY (EVENT_START_DT, SUBSCRIBER_CIRCLE_ID)
                  NOT LOGGED INITIALLY ;

INSERT INTO ?SCHEMA?.SUBSCRIBER_RATED_USAGE_COMPRESS
  (SELECT * FROM TE_TEMP.SUBSCRIBER_RATED_USAGE) ;

-- Create a regular index

CREATE INDEX ?SCHEMA?.INDEX_RATED_USAGE_COMPRESS 
  ON ?SCHEMA?.SUBSCRIBER_RATED_USAGE_COMPRESS
  (SUBSCRIBER_MSISDN) 
  ALLOW REVERSE SCANS ; 

-- Execute RUNSTATS to ensure current statistics in the index

CALL ADMIN_CMD('RUNSTATS ON TABLE ?SCHEMA?.SUBSCRIBER_RATED_USAGE_COMPRESS FOR INDEX ?SCHEMA?.INDEX_RATED_USAGE_COMPRESS') ;


-- Compress the table and index and REORG the table for compression to be effective

ALTER TABLE ?SCHEMA?.SUBSCRIBER_RATED_USAGE_COMPRESS  
  COMPRESS YES ;

CALL ADMIN_CMD('REORG TABLE ?SCHEMA?.SUBSCRIBER_RATED_USAGE_COMPRESS') ;

ALTER INDEX ?SCHEMA?.INDEX_RATED_USAGE_COMPRESS  
  COMPRESS YES ;

CALL ADMIN_CMD('REORG INDEXES ALL FOR TABLE ?SCHEMA?.SUBSCRIBER_RATED_USAGE_COMPRESS') ;




