-- Create table enabled for compression and populate with data

CREATE TABLE ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_COMPRESS  (
                  CDR_ID_KEY 			VARCHAR(75) ,
                  DED_ACC_KEY 		SMALLINT ,
                  DED_ACC_CHARGE_AMT 	DECIMAL(10,2) ,
                  SUBSCRIBER_MSISDN 	BIGINT ,
                  SUBSCRIBER_CIRCLE_ID 	SMALLINT ,
                  CC_NUM	 		VARCHAR(21) ,
                  EVENT_START_DT 		DATE ,
                  EVENT_START_TIME 		TIME ,
                  EVENT_DURATION 		INTEGER )
                  DISTRIBUTE BY HASH(SUBSCRIBER_MSISDN)			  
                    ORGANIZE BY (EVENT_START_DT, SUBSCRIBER_CIRCLE_ID)
                  NOT LOGGED INITIALLY ;

INSERT INTO ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_COMPRESS 
  (SELECT * FROM TE_TEMP.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE ) ;

-- Create a regular index

CREATE INDEX ?SCHEMA?.INDEX_DEDICATED_USAGE_COMPRESS 
  ON ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_COMPRESS
  (SUBSCRIBER_MSISDN) 
  ALLOW REVERSE SCANS ;

-- Execute RUNSTATS to ensure current statistics in the index

CALL ADMIN_CMD('RUNSTATS ON TABLE ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_COMPRESS FOR INDEX ?SCHEMA?.INDEX_DEDICATED_USAGE_COMPRESS') ;


-- Compress the table and index and REORG the table for compression to be effective

ALTER TABLE ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_COMPRESS 
  COMPRESS YES ;

CALL ADMIN_CMD('REORG TABLE ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_COMPRESS') ;

ALTER INDEX ?SCHEMA?.INDEX_DEDICATED_USAGE_COMPRESS 
  COMPRESS YES ;

CALL ADMIN_CMD('REORG INDEXES ALL FOR TABLE ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_COMPRESS') ;
