-- Create table SUBSCRIBER_RATED_USAGE_IND for indexing and populate the table with data

CREATE TABLE ?SCHEMA?.SUBSCRIBER_RATED_USAGE_IND  (
		  OUT_ROAMING_IND 		SMALLINT ,
                  OUT_ROAMING_NW_OP_KEY 	INTEGER ,
                  EVENT_START_DT 		DATE ,
                  EVENT_START_TIME 		TIME ,
                  EVENT_DURATION 		INTEGER ,
                  CORE_ACC_CHARGE_AMT 		DECIMAL(10,2) ,
                  CC_NUM 			VARCHAR(21) ,
                  EVENT_TYPE_KEY 		SMALLINT ,
                  CDR_ID_KEY 			VARCHAR(75) ,
                  EVENT_TYPE_CLSF_KEY 		SMALLINT ,
                  SUBSCRIBER_CIRCLE_ID 		SMALLINT ,
                  SUBSCRIBER_MSISDN 		BIGINT ,
                  CALL_PULSE_30 		INTEGER ,
                  CALL_PULSE_60 		INTEGER ,
                  FORWARD_TO_NUM 		BIGINT ,
                  FIRST_CELLSITE 		VARCHAR(21) ,
                  SOURCE_DESTINATION_NW_OP_KEY 	INTEGER ,
                  EVENT_DIR 			SMALLINT ,
                  TRF_PLAN_KEY 			VARCHAR(21) )
                  DISTRIBUTE BY HASH(SUBSCRIBER_MSISDN)
                  IN FACTSPACE INDEX IN INDSPACE1 NOT LOGGED INITIALLY ;

INSERT INTO ?SCHEMA?.SUBSCRIBER_RATED_USAGE_IND
  (SELECT * FROM TE_TEMP.SUBSCRIBER_RATED_USAGE) ;

-- Create a regular index

CREATE INDEX ?SCHEMA?.INDEX_RATED_USAGE_1 
  ON ?SCHEMA?.SUBSCRIBER_RATED_USAGE_IND
  (SUBSCRIBER_MSISDN) 
  ALLOW REVERSE SCANS ; 

-- Create a composite index

CREATE INDEX ?SCHEMA?.INDEX_RATED_USAGE_2 
  ON ?SCHEMA?.SUBSCRIBER_RATED_USAGE_IND
  (SUBSCRIBER_CIRCLE_ID, EVENT_START_DT) 
  ALLOW REVERSE SCANS ;

-- Execute RUNSTATS to ensure current statistics are present in the index

CALL ADMIN_CMD('RUNSTATS ON TABLE ?SCHEMA?.SUBSCRIBER_RATED_USAGE_IND FOR INDEXES ALL') ;


-- Create table SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_IND for indexing and populate the table with data

CREATE TABLE ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_IND (
                  CDR_ID_KEY 			VARCHAR(75) ,
                  DED_ACC_KEY 			SMALLINT ,
                  DED_ACC_CHARGE_AMT 		DECIMAL(10,2) ,
                  SUBSCRIBER_MSISDN 		BIGINT ,
                  SUBSCRIBER_CIRCLE_ID 		SMALLINT ,
                  CC_NUM	 		VARCHAR(21) ,
                  EVENT_START_DT 		DATE ,
                  EVENT_START_TIME 		TIME ,
                  EVENT_DURATION 		INTEGER )
                  DISTRIBUTE BY HASH(SUBSCRIBER_MSISDN)
                  IN FACTSPACE INDEX IN INDSPACE1 NOT LOGGED INITIALLY ;

INSERT INTO ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_IND
  (SELECT * FROM TE_TEMP.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE) ;

-- Create a regular index

CREATE INDEX ?SCHEMA?.INDEX_DEDICATED_USAGE_1 
  ON ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_IND
  (SUBSCRIBER_MSISDN) 
  ALLOW REVERSE SCANS ;

-- Create a composite index

CREATE INDEX ?SCHEMA?.INDEX_DEDICATED_USAGE_2 
  ON ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_IND
  (SUBSCRIBER_CIRCLE_ID, EVENT_START_DT)
  ALLOW REVERSE SCANS ;

CALL ADMIN_CMD('RUNSTATS ON TABLE ?SCHEMA?.SUBSCRIBER_DEDICATED_ACCOUNT_USAGE_IND FOR INDEXES ALL') ;
